#line 1 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner_intermediate.cpp"
#include <stdint.h>
// forward declare yyscan_t to improve type safety
#define YY_TYPEDEF_YY_SCANNER_T
struct yyguts_t;
typedef yyguts_t *yyscan_t;

#line 8 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner_intermediate.cpp"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define lexscannerYY_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer lexscannerYY_create_buffer
#endif

#ifdef yy_delete_buffer
#define lexscannerYY_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer lexscannerYY_delete_buffer
#endif

#ifdef yy_scan_buffer
#define lexscannerYY_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer lexscannerYY_scan_buffer
#endif

#ifdef yy_scan_string
#define lexscannerYY_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string lexscannerYY_scan_string
#endif

#ifdef yy_scan_bytes
#define lexscannerYY_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes lexscannerYY_scan_bytes
#endif

#ifdef yy_init_buffer
#define lexscannerYY_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer lexscannerYY_init_buffer
#endif

#ifdef yy_flush_buffer
#define lexscannerYY_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer lexscannerYY_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define lexscannerYY_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state lexscannerYY_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define lexscannerYY_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer lexscannerYY_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define lexscannerYYpush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state lexscannerYYpush_buffer_state
#endif

#ifdef yypop_buffer_state
#define lexscannerYYpop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state lexscannerYYpop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define lexscannerYYensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack lexscannerYYensure_buffer_stack
#endif

#ifdef yylex
#define lexscannerYYlex_ALREADY_DEFINED
#else
#define yylex lexscannerYYlex
#endif

#ifdef yyrestart
#define lexscannerYYrestart_ALREADY_DEFINED
#else
#define yyrestart lexscannerYYrestart
#endif

#ifdef yylex_init
#define lexscannerYYlex_init_ALREADY_DEFINED
#else
#define yylex_init lexscannerYYlex_init
#endif

#ifdef yylex_init_extra
#define lexscannerYYlex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra lexscannerYYlex_init_extra
#endif

#ifdef yylex_destroy
#define lexscannerYYlex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy lexscannerYYlex_destroy
#endif

#ifdef yyget_debug
#define lexscannerYYget_debug_ALREADY_DEFINED
#else
#define yyget_debug lexscannerYYget_debug
#endif

#ifdef yyset_debug
#define lexscannerYYset_debug_ALREADY_DEFINED
#else
#define yyset_debug lexscannerYYset_debug
#endif

#ifdef yyget_extra
#define lexscannerYYget_extra_ALREADY_DEFINED
#else
#define yyget_extra lexscannerYYget_extra
#endif

#ifdef yyset_extra
#define lexscannerYYset_extra_ALREADY_DEFINED
#else
#define yyset_extra lexscannerYYset_extra
#endif

#ifdef yyget_in
#define lexscannerYYget_in_ALREADY_DEFINED
#else
#define yyget_in lexscannerYYget_in
#endif

#ifdef yyset_in
#define lexscannerYYset_in_ALREADY_DEFINED
#else
#define yyset_in lexscannerYYset_in
#endif

#ifdef yyget_out
#define lexscannerYYget_out_ALREADY_DEFINED
#else
#define yyget_out lexscannerYYget_out
#endif

#ifdef yyset_out
#define lexscannerYYset_out_ALREADY_DEFINED
#else
#define yyset_out lexscannerYYset_out
#endif

#ifdef yyget_leng
#define lexscannerYYget_leng_ALREADY_DEFINED
#else
#define yyget_leng lexscannerYYget_leng
#endif

#ifdef yyget_text
#define lexscannerYYget_text_ALREADY_DEFINED
#else
#define yyget_text lexscannerYYget_text
#endif

#ifdef yyget_lineno
#define lexscannerYYget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno lexscannerYYget_lineno
#endif

#ifdef yyset_lineno
#define lexscannerYYset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno lexscannerYYset_lineno
#endif

#ifdef yyget_column
#define lexscannerYYget_column_ALREADY_DEFINED
#else
#define yyget_column lexscannerYYget_column
#endif

#ifdef yyset_column
#define lexscannerYYset_column_ALREADY_DEFINED
#else
#define yyset_column lexscannerYYset_column
#endif

#ifdef yywrap
#define lexscannerYYwrap_ALREADY_DEFINED
#else
#define yywrap lexscannerYYwrap
#endif

#ifdef yyalloc
#define lexscannerYYalloc_ALREADY_DEFINED
#else
#define yyalloc lexscannerYYalloc
#endif

#ifdef yyrealloc
#define lexscannerYYrealloc_ALREADY_DEFINED
#else
#define yyrealloc lexscannerYYrealloc
#endif

#ifdef yyfree
#define lexscannerYYfree_ALREADY_DEFINED
#else
#define yyfree lexscannerYYfree
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define lexscannerYYwrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 158
#define YY_END_OF_BUFFER 159
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_acclist[729] =
    {   0,
    16506,16506,  159,  158,    1,  158,  158,  158,   18,  158,
      158,   27,  158,    1,   18,   27,  158,   18,  158,   18,
      158,    8,  158,    9,  158,   10,  158,    1,    8,   10,
      158,    8,  158,    8,  158,    8,  158,  158,  158,   29,
      158,    1,   29,  158,   31,  158,  158,   33,  158,    1,
       31,   33,  158,   31,  158,   72,  158,   69,   72,  158,
       69,  158,    1,   69,   72,  158,   38,   72,  158,   56,
       72,  158,   72,  158,   72,  158,   44,   72,  158,   72,
      158,   72,  158,   68,   69,   72,  158,   67,   69,  158,
        1,   67,   69,   72,  158,   72,  158,   43,  158,    1,

       43,  158,   41,   43,  158,   43,  158,   42,   43,  158,
       51,  158,    1,   51,  158,   51,  158,   51,  158,   48,
       51,  158,   49,   51,  158,   65,  158,   64,   65,  158,
       63,  158,    1,   63,   65,  158,   59,   65,  158,   61,
       65,  158,   62,   65,  158,   58,   65,  158,   65,  158,
       65,  158,   54,  158,   53,   54,  158,    1,   53,   54,
      158,   55,  158,  158,  157,  158,    1,  157,  158,  158,
       15,  158,    1,   15,  158,  158,  158,   17,  158,    1,
       17,  158,  158,   23,   26,  158,   25,  158,    1,   23,
       25,   26,  158,   26,  158,   23,   26,  158,   84,   89,

      158,   84,   89,  158,   95,  158,    1,   84,   89,  158,
       81,   89,  158,   89,  158,   88,   89,  158,   89,  158,
       89,  158,   84,   89,  158,   84,   89,  158,   84,   89,
      158,   77,   89,  158,   79,   89,  158,   84,   89,  158,
       82,   89,  158,  156,  158,   75,  158,   76,  158,    1,
       75,  158,   75,  158,  158,16506,  158,16506,  123,  158,
        1,  158,16506,  158,16506,  138,  140,  158,  138,  140,
      158,  139,  158,    1,  138,  140,  158,  140,  158,  140,
      158,  138,  140,  158,  140,  158,  140,  158,  138,  140,
      158,  140,  158,  140,  158,  138,  140,  158,  140,  158,

      151,  154,  158,  153,  158,    1,  151,  154,  158,  154,
      158,  154,  158,  154,  158,  154,  158,  154,  158,  151,
      154,  158, 8340,  154,  158,16529,16530,16531,16532,  151,
      154,  158,  154,  158,  100,  158,   99,  158,    1,  100,
      158,   97,  100,  158,  100,  158,  100,  158,  100,  158,
      117,  118,  158,  119,  158,    1,  117,  118,  158,  118,
      158,  112,  158,  112,  158,  113,  158,    1,  112,  158,
      115,  158,  112,  158,  158,  102,  158,    1,  158,  158,
      108,  110,  158,  103,  110,  158,  103,  158,    1,  103,
      110,  158,  110,  158,  110,  158,  110,  158,  108,  110,

      158,   28,   28,   27,   20,    8,    9,   10,    8,    8,
        8,    4,   29,   29,   29,   32,   32,   33,   66,   69,
       52,   71,   36,   35,   35,   35,   70,   37,   68,   67,
       67,   67,   69,   40,   39,   46,   50,   47,   63,   60,
       60,   57,   53,  157,  157,  157,   15,   15,   15,   14,
       15,   14,   15,   17,   17,   17,   23,   25,   22,   24,
       23,   24,   84,   84,   84,   84,   84,   85,   86,   84,
       82,   74,16506,  123,16506,16506,16506,  138,  138,  138,
      124,  129,  128,  138,  138,  138,  138,  125,  126,  125,
      126,  125,  125,  125,  126,  125,  126,  127,  128,  138,

      151,  152,  151, 8340,16529,16530,16531,16532,  151, 8337,
     8340, 8337, 8340, 8339, 8339,  151,   98,   96,  117,  116,
      112,  112,  114,  111,  111,  112,  102,  101,  102,  108,
      103,  109,  104,  105,  108,  108,  108,  108,   19,   19,
       28,   20,   11,   11,   13,   13,    8,    8,    8,   32,
       30,   30,   14,   15,   16,   17,   16,   17,   21,   21,
       87,   90,   93,   83,16506,  138,  138,  131,  138,  125,
      127,  127,  136,  138,  135,  143,  151, 8337, 8340, 8338,
     8339,  150,  151,  149,  116,  108,  108,  108,  108,   19,
        8,    8,    8,   45,   16,   17,   87,   92,   94,   94,

      120,16506,  138,  138,  130,  130,  138,  136,  126,  136,
      138,  135,  151, 8337, 8340, 8338,  150,  150,  151,  149,
      116,  108,  108,  108,  108,    8,    8,    8,   73,   91,
       80,  155,  120,16506,  121,  123,  132,  138,  138,  134,
      136, 8337, 8340,  150,  116,  106,  108,  108,  108,  108,
      108,  108,   12,   12,    8,    8,    8,   36, 8314,  137,
      138,  141,  116,  108,  108,  108,  108,  108,    2,    8,
        8,    3,    8,    8,   34,  142,  116,  108,  108,  108,
      108,  108,    8,    8,    3,    3,    8,   78,  144,  116,
      107,  108,  108,  108,  108,  108,    8,    8,    5,    8,

      116,  108,  108,    8,    8,  133,  116,  108,  108,    8,
        8,  116,  108,  108,    6,    8,    8,  116,    8,  116,
        8,  116,    7,    8,  116,  116,  116,  116
    } ;

static const flex_int16_t yy_accept[798] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    4,    5,    7,
        8,    9,   11,   12,   14,   18,   20,   22,   24,   26,
       28,   32,   34,   36,   38,   39,   40,   42,   45,   47,
       48,   50,   54,   56,   58,   61,   63,   67,   70,   73,
       75,   77,   80,   82,   84,   88,   91,   96,   98,  100,

      103,  106,  108,  111,  113,  116,  118,  120,  123,  126,
      128,  131,  133,  137,  140,  143,  146,  149,  151,  153,
      155,  158,  162,  164,  165,  167,  170,  171,  173,  176,
      177,  178,  180,  183,  184,  187,  189,  194,  196,  199,
      202,  205,  207,  211,  214,  216,  219,  221,  223,  226,
      229,  232,  235,  238,  241,  244,  246,  248,  250,  253,
      255,  257,  259,  261,  264,  266,  269,  272,  274,  278,
      280,  282,  285,  287,  289,  292,  294,  296,  299,  301,
      304,  306,  310,  312,  314,  316,  318,  320,  323,  330,
      333,  335,  337,  339,  342,  345,  347,  349,  351,  354,

      356,  360,  362,  364,  366,  368,  371,  373,  375,  376,
      378,  380,  381,  384,  387,  389,  393,  395,  397,  399,
      402,  402,  402,  402,  402,  403,  404,  404,  405,  405,
      405,  405,  406,  407,  408,  409,  410,  411,  412,  412,
      413,  413,  414,  415,  416,  416,  417,  418,  419,  419,
      419,  420,  421,  422,  423,  423,  423,  424,  425,  426,
      428,  428,  429,  430,  431,  432,  434,  435,  436,  436,
      437,  438,  439,  440,  441,  442,  442,  443,  444,  444,
      445,  446,  447,  447,  448,  449,  450,  452,  454,  454,
      455,  456,  457,  457,  458,  459,  460,  461,  463,  464,

      465,  465,  466,  467,  468,  468,  468,  468,  469,  470,
      470,  470,  470,  471,  472,  472,  472,  472,  473,  474,
      475,  476,  477,  477,  477,  478,  479,  480,  481,  481,
      482,  483,  484,  485,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  487,  487,  487,
      488,  488,  490,  492,  493,  494,  496,  498,  500,  501,
      501,  502,  503,  503,  503,  503,  504,  509,  510,  510,
      512,  514,  515,  516,  516,  517,  517,  518,  519,  520,
      520,  521,  522,  523,  523,  524,  525,  527,  527,  528,
      528,  530,  531,  532,  533,  534,  535,  536,  537,  538,

      539,  539,  539,  540,  541,  542,  543,  544,  545,  545,
      546,  547,  548,  549,  550,  551,  552,  553,  553,  553,
      553,  555,  557,  559,  559,  560,  561,  561,  561,  562,
      562,  562,  563,  563,  563,  564,  564,  564,  565,  565,
      565,  565,  565,  565,  566,  567,  568,  568,  568,  568,
      569,  569,  569,  569,  569,  569,  569,  569,  569,  569,
      569,  570,  571,  572,  572,  572,  572,  573,  573,  575,
      576,  576,  576,  576,  577,  578,  580,  581,  582,  582,
      584,  585,  585,  586,  587,  588,  589,  590,  590,  591,
      591,  592,  593,  594,  594,  595,  597,  597,  597,  598,

      598,  599,  599,  599,  600,  601,  601,  601,  601,  602,
      603,  604,  605,  606,  607,  607,  607,  607,  607,  607,
      607,  607,  607,  607,  607,  607,  607,  607,  608,  608,
      609,  610,  612,  613,  613,  613,  613,  614,  616,  617,
      618,  620,  621,  621,  622,  623,  624,  625,  626,  626,
      626,  627,  628,  629,  629,  630,  630,  630,  630,  631,
      631,  631,  631,  632,  633,  633,  634,  634,  635,  637,
      639,  640,  640,  641,  641,  641,  641,  641,  641,  641,
      641,  641,  641,  642,  642,  642,  642,  642,  642,  642,
      642,  642,  642,  642,  642,  642,  644,  645,  645,  646,

      648,  649,  650,  651,  652,  653,  653,  654,  655,  656,
      657,  658,  659,  659,  659,  660,  662,  662,  662,  662,
      662,  662,  662,  662,  662,  662,  662,  662,  663,  663,
      663,  663,  663,  663,  663,  663,  663,  663,  663,  663,
      663,  663,  664,  665,  666,  667,  668,  669,  670,  671,
      672,  672,  674,  675,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  677,  677,  677,
      677,  677,  677,  677,  677,  677,  677,  677,  677,  677,
      678,  679,  680,  681,  682,  683,  684,  685,  686,  687,
      688,  688,  689,  689,  689,  689,  689,  689,  689,  689,

      690,  690,  690,  690,  690,  690,  690,  690,  690,  690,
      691,  693,  694,  695,  696,  697,  698,  699,  701,  701,
      701,  701,  701,  701,  701,  701,  701,  701,  701,  701,
      701,  701,  701,  702,  703,  704,  705,  706,  706,  706,
      707,  707,  707,  707,  707,  707,  707,  707,  707,  707,
      707,  708,  709,  710,  711,  712,  712,  712,  712,  712,
      712,  712,  712,  712,  713,  714,  715,  717,  718,  718,
      718,  718,  718,  719,  720,  720,  720,  720,  721,  722,
      722,  722,  722,  723,  725,  725,  725,  726,  726,  726,
      727,  727,  727,  728,  728,  729,  729

    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    7,    8,    9,   10,    1,   11,   12,
       13,   14,    1,    1,   15,   16,   17,   18,   18,   18,
       18,   18,   18,   18,   18,   19,   20,   21,    1,   22,
       23,   24,   25,   26,   27,   27,   28,   29,   30,   31,
       27,   27,   27,   27,   27,   32,   27,   27,   33,   34,
       27,   35,   27,   27,   36,   27,   27,   27,   27,   27,
       37,   38,   39,    1,   27,   40,   41,   42,   43,   44,

       45,   46,   47,   48,   49,   27,   50,   51,   52,   53,
       54,   55,   27,   56,   57,   58,   59,   60,   27,   61,
       62,   27,   63,   64,   65,   66,    1,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,

       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67
    } ;

static const YY_CHAR yy_meta[68] =
    {   0,
        1,    2,    3,    4,    2,    1,    5,    5,    6,    1,
        7,    8,    9,   10,   11,   12,   13,   14,   14,   14,
        1,   15,    1,    1,    1,   16,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   17,    1,   18,   19,   20,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       17,   17,   21,    1,    5,   22,   23
    } ;

static const flex_int16_t yy_base[908] =
    {   0,
     3729, 3728,    0,    3,   19,   23,    5,    7,   12,   15,
     3727,   27,   78,  140,   31,   38,   46,   48,   54,   59,
       64,   67,  116,  156,   43,  104,   36,   40,   56,   69,
       84,  121,  123,  132,  218,  282,   29,   44,  107,  163,
      169,  178,  210,  346,  256,  411,  193,  254,  109,  135,
      185,  298,  201,  205,  326,  353, 3730, 3734, 3734, 3675,
     3711, 3734,  321, 3734, 3724,  188,  116,    0,  228, 3734,
     3723, 3676, 3668, 3678, 3715,  152, 3734,  161, 3734,  172,
     3734, 3718, 3710, 3734,  232, 3734, 3716, 3734, 3693, 3703,
       42, 3734,  473, 3651,  330, 3734, 3712, 3704, 3734, 3734,

     3734,  178, 3734, 3734, 3734, 3692,  225, 3734, 3734, 3734,
     3734, 3734, 3709, 3734, 3734, 3734, 3734,  534, 3646, 3734,
     3734, 3707, 3734,  188, 3734,  214,  263, 3734,  271,  276,
      294, 3734,  302,  306,    0, 3734, 3706, 3691,  224,    0,
      372, 3734,    0, 3734,  247, 3669,  255, 3734, 3671, 3698,
      272, 3734,  385,  422,  311,  393, 3734, 3734, 3734, 3697,
     3700,  436,  376, 3699,  336,    0,  360, 3734,    0,  359,
      386,  389,  574, 3734,  450,  635,  392, 3661, 3634,    0,
     3734,    0, 3734, 3682,  404, 3681,  291,  454,  520, 3657,
     3630, 3734, 3734, 3734, 3734, 3678,  405,    0,    0, 3734,

        0, 3687,    0,  460, 3734,    0, 3676,  412,   51, 3734,
      308,  316,    0,  443,  496,  500, 3675, 3734,  426,  470,
     3636,  431,  457,  504, 3734,  466,  479, 3734,  472, 3636,
      484, 3734,    0,  461, 3734, 3632, 3643, 3642, 3679, 3734,
      488, 3734,  514, 3734,  523, 3734,  525, 3734,  539,  543,
     3734, 3734, 3734, 3734, 3661,  297, 3734, 3734, 3734, 3734,
     3619, 3734,  547, 3734, 3680, 3734, 3734, 3734, 3661, 3734,
     3734, 3734, 3734, 3734, 3734, 3616, 3734, 3734,  550, 3734,
      558, 3734,  560, 3734,  562, 3734, 3734,  564,  566, 3734,
      571, 3734,  573,    0, 3734,  576, 3734,    0,    0,  701,

      580, 3645, 3672,  340,  585, 3667, 3659,  241,  589, 3664,
      611,  575,  703,  591,  710,  584, 3668, 3734, 3671,  702,
      715,  382,  723, 3656,  585,    0,  719,  688,  607, 3734,
     3734, 3734,  479, 3618,    0, 3617, 3616,  714, 3611, 3617,
     3626,  360, 3608, 3607, 3619, 3611,  742,  808, 3645, 3621,
     3594, 3734,  740,  615, 3734, 3619, 3592,  744, 3617, 3590,
        0, 3734,  720, 3602,  760,  874,  878, 3614, 3587,  882,
      763,    0, 3734, 3612, 3611, 3584, 3734, 3734,    0, 3642,
     3641,    0,  769, 3630, 3734, 3734,    0,  433, 3734,  493,
     3734,    0,  782, 3734, 3734, 3734, 3587, 3579, 3574, 3573,

     3551,  580, 3734,  605, 3734,  726, 3734, 3605, 3547, 3734,
     3592, 3532, 3533, 3519, 3734, 3734, 3560,  359, 3541, 3517,
     3734, 3734,  749,  786, 3734, 3546,  774, 3529, 3734, 3522,
      522, 3734, 3512,  889, 3734, 3503, 3504, 3734,  613,  467,
      764,  538,  744,  778,  727, 3466,  948, 3459,  835, 3734,
     3442, 3438, 3422, 3418, 3414, 3421, 3411, 3407, 3385, 3383,
     1014,    0,  893, 1015, 3385, 3384,  895, 3404, 3371, 3336,
      701,  854, 3351, 3734, 1016, 1020,  798,    0, 3348, 3339,
     3312, 3365, 3358, 3312, 3305, 3293, 3277, 3283, 3734, 3263,
     3266, 3261, 3245,  773, 3734, 3734,  897, 3285, 3734,  787,

     3734,  921, 3273, 3734,  897, 3274, 3258, 3250, 1024,  910,
     3245, 3221, 3734,    0,    0, 3205, 3199,    0, 3183, 3169,
     3173, 3163, 3159, 3150, 3139, 3146, 3127,  914,  868, 3132,
     3734, 3131, 3099,  876,  887, 1015,  928, 1037, 1085, 3117,
     3114, 3069, 3119, 3112, 3067,  984, 3045, 3060, 3042,  934,
     3074, 3019, 3017, 3042, 3734, 3046, 3045, 1089, 3734,  915,
     3036, 3031, 3028, 3734, 1047, 3734, 2962, 1067, 1030,    0,
     2996, 2957, 3734, 2956, 2959, 2935, 2940, 2949, 2921, 2907,
     2917, 2898, 2896, 1008, 2904, 2865, 2864, 2854, 2853, 2860,
     1038, 2842, 2830, 2828, 2814, 1094, 2814, 2824, 2806,    0,

     2744, 2724, 2729, 2671, 2674, 2660, 3734, 2704, 1006, 1099,
     2665, 2681, 2655, 2645, 3734,    0, 2598, 2590, 2586, 2582,
     2569, 2565, 2559, 2550, 2550, 2556, 2582, 3734, 2560, 1057,
     2551, 2552, 2542, 2546, 2542, 2554, 2550, 2544, 2535, 2538,
     2581, 2579, 2541, 2535, 2527, 2526, 2523, 3734, 2523, 2523,
     1100,  941, 2522, 3734, 2558, 2552, 2516, 2513, 2522, 2508,
     2496, 2510, 2489, 2453, 2448, 2426, 3734, 2436, 2417,    0,
     2400, 2378, 2345, 2244, 2245, 2185, 2196, 2182, 2223, 2222,
     2183, 2132, 2141, 2134, 2117, 2116, 2116, 1063, 1104, 2085,
     2125, 3734, 2060, 2047, 2056, 2055, 2053, 2051, 2048, 3734,

     2046, 2054, 2036, 2042, 2052, 2035, 2044, 2031, 2074, 2072,
        0, 2027, 2028, 2010, 2007, 2012, 2012,    0, 2034, 1947,
     1919,    0, 1923, 1919, 1913, 1913, 1915, 1915, 1907, 1898,
     1903, 1931, 1924, 1801, 1781, 1787, 1758, 1781, 1650, 3734,
     1650, 1070, 1079, 1066, 1056, 1073, 1054, 1065, 1051, 1105,
     1104, 1069, 1058, 1039, 1029, 1049,  983,  989,  975,  896,
      894,  889,  932,  894,  826,  755,    0,  742,  704,  657,
      571,  603,  552,  504,  477,  428,  435,  404,  309,  349,
      282,  281,  238,    0,  216,  204,  199,  189,  177,  144,
      120,   92,   70,   24, 3734, 3734, 1123, 1146, 1169, 1192,

     1215, 1238, 1261, 1284, 1307, 1330, 1353, 1376, 1399, 1422,
     1445, 1468, 1491, 1514, 1537, 1560, 1583, 1606, 1629, 1652,
     1675, 1698, 1721, 1744, 1767, 1790, 1813, 1836, 1859, 1882,
     1905, 1928, 1951, 1974, 1997, 2020, 2043, 2066, 2088, 2111,
     2134, 2157, 2180, 2203, 2226, 2249, 2272, 2295, 2318, 2341,
     2364, 2387, 2410, 2433, 2456, 2479, 2502, 2525, 2059, 2548,
     2570, 2588, 2611, 2634, 2657, 2680, 2703, 2726, 2749, 2772,
     2795, 2818, 2841, 2864, 2887, 2910, 2933, 2956, 2979, 3002,
     3025, 3048, 3071, 3094, 3117, 3140, 3163, 3186, 3209, 3232,
     3255, 3278, 3301, 3324, 3347, 3370, 3393, 3416, 3439, 3462,

     3485, 3508, 3531, 3554, 3577, 3600, 3623
    } ;

static const flex_int16_t yy_def[908] =
    {   0,
      797,  797,  797,  798,  799,  799,  797,  797,  800,  800,
      797,  801,  802,  802,  803,  803,  803,  803,  804,  804,
      804,  804,  805,  805,  806,  806,  807,  807,  808,  808,
      809,  809,  810,  810,  811,  811,  797,  797,  812,  812,
      813,  813,  814,  814,  815,  815,  816,  816,  817,  817,
      818,  818,  819,  819,  820,  820,  796,  796,  796,  796,
      796,  796,  821,  796,  796,  796,  796,  822,  796,  796,
      822,  822,  822,  822,  823,  824,  796,  824,  796,  825,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,
      826,  796,  796,  827,  796,  796,  796,  796,  796,  796,

      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  828,  796,
      796,  796,  796,  829,  796,  829,  830,  796,  830,  830,
      831,  796,  831,  831,  832,  796,  832,  796,  832,  833,
      833,  796,  833,  796,  796,  834,  796,  796,  833,  833,
      833,  796,  796,  833,  796,  796,  796,  796,  796,  835,
      836,  836,  796,  836,  836,  837,  837,  796,  837,  796,
      796,  837,  796,  796,  837,  796,  796,  837,  796,  838,
      796,  838,  796,  796,  796,  796,  796,  838,  839,  838,
      796,  796,  796,  796,  796,  796,  796,  840,  841,  796,

      841,  842,  843,  843,  796,  843,  796,  843,  844,  796,
      844,  844,  845,  796,  796,  796,  796,  796,  796,  845,
      796,  846,  847,  847,  796,  847,  847,  796,  796,  796,
      796,  796,  848,  796,  796,  848,  848,  848,  849,  796,
      850,  796,  850,  796,  851,  796,  851,  796,  796,  796,
      796,  796,  796,  796,  852,  852,  796,  796,  796,  796,
      827,  796,  796,  796,  796,  796,  796,  796,  853,  796,
      796,  796,  796,  796,  796,  828,  796,  796,  829,  796,
      829,  796,  830,  796,  830,  796,  796,  830,  831,  796,
      831,  796,  831,  832,  796,  796,  796,  832,  833,  833,

      796,  833,  833,  833,  796,  854,  855,  796,  796,  856,
      796,  796,  833,  796,  796,  796,  857,  796,  858,  796,
      858,  858,  796,  796,  858,  837,  837,  837,  796,  796,
      796,  796,  837,  837,  859,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  837,  796,  796,  837,
      796,  796,  796,  348,  796,  796,  796,  796,  837,  796,
      860,  796,  796,  796,  796,  860,  861,  860,  796,  796,
      796,  862,  796,  796,  860,  796,  796,  796,  863,  864,
      864,  865,  865,  796,  796,  796,  865,  866,  796,  866,
      796,  867,  796,  796,  796,  796,  867,  867,  867,  867,

      796,  868,  796,  868,  796,  869,  796,  796,  796,  796,
      796,  870,  870,  870,  796,  796,  796,  852,  853,  796,
      796,  796,  831,  796,  796,  796,  796,  871,  796,  796,
      796,  796,  872,  796,  796,  873,  874,  796,  796,  796,
      796,  796,  796,  858,  837,  837,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,
      837,  348,  796,  796,  796,  796,  796,  875,  837,  796,
      796,  796,  796,  796,  860,  796,  796,  862,  796,  860,
      796,  876,  876,  867,  867,  867,  867,  796,  796,  796,
      870,  870,  870,  852,  796,  796,  796,  877,  796,  796,

      796,  796,  796,  796,  796,  878,  796,  796,  796,  858,
      837,  837,  796,  447,  447,  796,  796,  879,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  837,  796,  796,
      796,  837,  796,  796,  796,  796,  860,  796,  796,  796,
      860,  796,  880,  880,  867,  867,  867,  867,  796,  796,
      870,  870,  870,  852,  796,  796,  796,  796,  796,  796,
      872,  881,  796,  796,  796,  796,  796,  858,  796,  837,
      837,  796,  796,  796,  796,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  882,  882,  867,

      867,  867,  867,  867,  867,  796,  796,  796,  870,  870,
      870,  796,  883,  796,  796,  837,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,
      884,  884,  867,  867,  867,  867,  867,  796,  870,  870,
      796,  870,  870,  796,  885,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  886,
      796,  796,  796,  796,  796,  796,  796,  796,  887,  887,
      867,  867,  867,  867,  867,  870,  870,  796,  796,  870,
      888,  796,  796,  796,  796,  796,  796,  796,  796,  796,

      796,  796,  796,  796,  796,  796,  796,  796,  889,  889,
      867,  867,  867,  867,  867,  870,  870,  870,  890,  796,
      796,  891,  796,  796,  796,  796,  796,  796,  796,  796,
      796,  892,  892,  867,  867,  870,  870,  893,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  894,
      894,  867,  867,  870,  870,  895,  796,  796,  796,  796,
      796,  796,  896,  896,  867,  867,  870,  870,  897,  796,
      796,  898,  898,  870,  899,  796,  900,  900,  870,  901,
      796,  902,  902,  870,  903,  904,  904,  905,  906,  906,
      907,  796,  796,  796,  796,    0,  796,  796,  796,  796,

      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,

      796,  796,  796,  796,  796,  796,  796
    } ;

static const flex_int16_t yy_nxt[3802] =
    {   0,
      796,  796,  796,   59,   63,   64,   65,   63,   59,   60,
       59,   75,   66,   75,   77,   78,   61,   77,   78,   67,
       69,   70,   71,   69,   69,   70,   71,   69,   80,   81,
       82,   80,   59,   58,  100,  438,   83,  101,  125,  126,
       58,  100,  125,  126,  101,  121,  122,   59,   58,  100,
       58,  100,  103,  389,  103,  123,   58,  105,  128,  129,
       72,   58,  105,  256,   72,  257,   58,  105,  102,   58,
      105,  128,  129,   73,   74,  102,  795,   73,   74,   85,
       86,   87,   85,  102,   88,  102,  132,  133,  390,   89,
      106,  107,  108,  156,   90,  106,  107,  108,  795,   91,

      106,  107,  109,  106,  107,  109,  121,  122,  156,  158,
      159,  200,  201,  160,   92,   93,  123,  111,  112,  113,
      111,  202,  114,  132,  133,  136,  137,  115,  116,  232,
      134,  438,  222,  130,  136,  137,  138,  200,  201,  139,
       94,   95,   96,   97,   95,  138,   88,  202,  139,   98,
      793,   89,  117,  118,  242,  243,   90,  111,  112,  113,
      111,   91,  114,  244,  243,  158,  159,  115,  116,  160,
      162,  163,  164,  162,  246,  247,   92,   93,  119,  162,
      163,  164,  162,  793,  267,  165,  204,  205,  206,  204,
      280,  281,  117,  118,  165,  193,  194,  229,  207,  195,

      438,  208,   94,  210,  211,  790,  196,  210,  211,  197,
      790,  167,  168,  169,  167,  268,  282,  281,  119,  141,
      142,  143,  141,  170,  144,  145,  171,  438,  146,  234,
      198,  172,  234,  250,  147,  173,  250,  297,  212,  148,
      298,  221,  212,  148,  787,  230,  432,  173,  305,  149,
      231,  305,  150,  149,  433,  148,  193,  194,  181,  182,
      195,  270,  271,  272,  183,  284,  285,  196,  308,  184,
      197,  309,  185,  286,  285,  174,  151,  186,  287,  288,
      152,  187,  153,  154,  142,  143,  154,  787,  144,  155,
      302,  198,  146,  187,  183,  251,  290,  291,  147,  204,

      205,  206,  204,  148,  292,  291,  303,  148,  290,  291,
      389,  207,  305,  149,  208,  305,  150,  149,  391,  148,
      257,  183,  224,  225,  226,  224,  418,  214,  215,  216,
      214,  263,  264,  265,  263,  364,  365,  227,  320,  217,
      151,  218,  219,  670,  152,  390,  153,  175,  168,  169,
      175,  220,  325,  390,  214,  215,  216,  214,  302,  176,
      438,  327,  177,  220,  327,  784,  217,  172,  218,  219,
      293,  173,  329,  300,  303,  330,  300,  323,  220,  301,
      323,  328,  257,  173,  320,  178,  311,  311,  311,  311,
      220,  494,  324,  251,  315,  315,  315,  315,  325,  331,

      454,  312,  332,  302,  455,  331,  303,  302,  358,  316,
      783,  179,  188,  181,  182,  188,  456,  362,  377,  183,
      362,  377,  333,  313,  189,  386,  313,  185,  387,  314,
      304,  334,  186,  403,  404,  389,  187,  321,  320,  395,
      321,  783,  396,  333,  393,  393,  393,  393,  187,  183,
      190,  347,  322,  302,  347,  366,  303,  302,  366,  225,
      226,  383,  234,  348,  383,  234,  349,  367,  405,  226,
      390,  328,  507,  384,  407,  408,  191,  258,  781,  258,
      304,  225,  226,  507,  258,  259,  410,  411,  438,  350,
      242,  243,  406,  368,  258,  391,  259,  393,  393,  393,

      393,  393,  393,  393,  393,  224,  225,  226,  224,  258,
      260,  259,  397,  445,  398,  351,  244,  243,  399,  369,
      227,  370,  371,  371,  370,  246,  247,  415,  247,  400,
      390,  373,  499,  367,  445,  258,  362,  259,  274,  500,
      274,  416,  417,  508,  250,  274,  275,  250,  263,  264,
      265,  263,  280,  281,  508,  274,  779,  275,  778,  374,
      282,  281,  284,  285,  286,  285,  421,  285,  290,  291,
      274,  274,  275,  292,  291,  422,  423,  424,  425,  426,
      424,  305,  403,  404,  305,  369,  305,  320,  439,  305,
      434,  440,  305,  434,  435,  305,  274,  441,  275,  335,

      442,  444,  427,  427,  427,  436,  251,  489,  404,  778,
      251,  335,  311,  311,  311,  311,  336,  337,  507,  338,
      329,  339,  340,  330,  341,  342,  507,  312,  354,  343,
      344,  330,  670,  345,  346,  352,  353,  352,  352,  353,
      352,  352,  352,  352,  352,  352,  352,  352,  354,  352,
      352,  330,  355,  355,  355,  352,  352,  352,  352,  352,
      352,  355,  355,  355,  355,  355,  355,  355,  355,  355,
      355,  352,  352,  352,  356,  355,  355,  355,  355,  355,
      355,  355,  355,  355,  355,  355,  355,  355,  355,  355,
      355,  355,  355,  355,  355,  355,  355,  352,  352,  352,

      357,  352,  300,  323,  313,  300,  323,  313,  301,  776,
      314,  315,  315,  315,  315,  438,  321,  320,  324,  321,
      327,  333,  450,  327,  323,  450,  316,  323,  225,  226,
      334,  322,  302,  534,  302,  303,  302,  303,  302,  324,
      328,  464,  333,  461,  464,  467,  461,  471,  467,  509,
      450,  496,  291,  472,  534,  348,  511,  468,  349,  304,
      509,  304,  471,  328,  371,  371,  371,  371,  474,  508,
      383,  511,  474,  383,  472,  497,  450,  508,  497,  465,
      320,  350,  384,  393,  393,  393,  393,  424,  425,  426,
      424,  427,  427,  427,  510,  774,  257,  429,  474,  539,

      539,  539,  539,  554,  557,  351,  711,  351,  352,  353,
      352,  352,  353,  352,  352,  352,  352,  352,  352,  352,
      352,  462,  352,  352,  474,  355,  355,  355,  352,  352,
      352,  352,  352,  352,  355,  355,  355,  355,  355,  355,
      355,  355,  355,  355,  352,  352,  352,  356,  355,  355,
      355,  355,  355,  355,  355,  355,  355,  355,  355,  355,
      355,  355,  355,  355,  355,  355,  355,  355,  355,  355,
      352,  352,  352,  357,  352,  475,  711,  517,  475,  370,
      371,  371,  370,  476,  371,  371,  476,  367,  535,  373,
      434,  367,  518,  434,  467,  477,  467,  467,  497,  467,

      773,  497,  432,  555,  584,  503,  468,  465,  468,  535,
      561,  568,  569,  368,  568,  528,  585,  374,  528,  584,
      432,  374,  558,  559,  558,  558,  510,  348,  561,  537,
      349,  585,  537,  351,  502,  328,  607,  608,  773,  369,
      670,  367,  689,  369,  771,  689,  670,  369,  513,  513,
      513,  513,  513,  513,  513,  513,  514,  513,  513,  513,
      513,  513,  513,  513,  513,  515,  515,  515,  513,  513,
      513,  513,  513,  513,  515,  515,  515,  515,  515,  515,
      515,  515,  515,  515,  513,  513,  513,  513,  515,  515,
      515,  515,  515,  515,  515,  515,  515,  515,  515,  515,

      515,  515,  515,  515,  515,  515,  515,  515,  515,  515,
      513,  513,  513,  513,  514,  528,  529,  537,  528,  529,
      537,  538,  371,  371,  538,  565,  601,  348,  565,  367,
      349,  323,  602,  477,  323,  328,  670,  627,  596,  371,
      371,  596,  770,  603,  518,  566,  324,  649,  565,  567,
      477,  565,  627,  350,  465,  368,  650,  586,  587,  374,
      438,  567,  588,  589,  689,  590,  591,  689,  568,  569,
      592,  568,  567,  593,  594,  595,  374,  768,  634,  351,
      351,  369,  635,  767,  567,  369,  539,  539,  539,  539,
      558,  559,  558,  558,  636,  596,  371,  371,  596,  669,

      651,  651,  369,  651,  651,  689,  766,  477,  689,  765,
      764,  764,  670,  762,  670,  670,  670,  670,  761,  760,
      759,  652,  688,   58,   58,   58,   58,   58,   58,   58,
       58,   58,   58,   58,   58,   58,   58,   58,   58,   58,
       58,   58,   58,   58,   58,   58,   62,   62,   62,   62,
       62,   62,   62,   62,   62,   62,   62,   62,   62,   62,
       62,   62,   62,   62,   62,   62,   62,   62,   62,   68,
       68,   68,   68,   68,   68,   68,   68,   68,   68,   68,
       68,   68,   68,   68,   68,   68,   68,   68,   68,   68,
       68,   68,   76,   76,   76,   76,   76,   76,   76,   76,

       76,   76,   76,   76,   76,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   79,   79,   79,   79,   79,
       79,   79,   79,   79,   79,   79,   79,   79,   79,   79,
       79,   79,   79,   79,   79,   79,   79,   79,   84,   84,
       84,   84,   84,   84,   84,   84,   84,   84,   84,   84,
       84,   84,   84,   84,   84,   84,   84,   84,   84,   84,
       84,   99,   99,   99,   99,   99,   99,   99,   99,   99,
       99,   99,   99,   99,   99,   99,   99,   99,   99,   99,
       99,   99,   99,   99,  104,  104,  104,  104,  104,  104,
      104,  104,  104,  104,  104,  104,  104,  104,  104,  104,

      104,  104,  104,  104,  104,  104,  104,  110,  110,  110,
      110,  110,  110,  110,  110,  110,  110,  110,  110,  110,
      110,  110,  110,  110,  110,  110,  110,  110,  110,  110,
      120,  120,  120,  120,  120,  120,  120,  120,  120,  120,
      120,  120,  120,  120,  120,  120,  120,  120,  120,  120,
      120,  120,  120,  124,  124,  124,  124,  124,  124,  124,
      124,  124,  124,  124,  124,  124,  124,  124,  124,  124,
      124,  124,  124,  124,  124,  124,  127,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  127,  127,  127,  131,

      131,  131,  131,  131,  131,  131,  131,  131,  131,  131,
      131,  131,  131,  131,  131,  131,  131,  131,  131,  131,
      131,  131,  135,  135,  135,  135,  135,  135,  135,  135,
      135,  135,  135,  135,  135,  135,  135,  135,  135,  135,
      135,  135,  135,  135,  135,  140,  140,  140,  140,  140,
      140,  140,  140,  140,  140,  140,  140,  140,  140,  140,
      140,  140,  140,  140,  140,  140,  140,  140,  157,  157,
      157,  157,  157,  157,  157,  157,  157,  157,  157,  157,
      157,  157,  157,  157,  157,  157,  157,  157,  157,  157,
      157,  161,  161,  161,  161,  161,  161,  161,  161,  161,

      161,  161,  161,  161,  161,  161,  161,  161,  161,  161,
      161,  161,  161,  161,  166,  166,  166,  166,  166,  166,
      166,  166,  166,  166,  166,  166,  166,  166,  166,  166,
      166,  166,  166,  166,  166,  166,  166,  180,  180,  180,
      180,  180,  180,  180,  180,  180,  180,  180,  180,  180,
      180,  180,  180,  180,  180,  180,  180,  180,  180,  180,
      192,  192,  192,  192,  192,  192,  192,  192,  192,  192,
      192,  192,  192,  192,  192,  192,  192,  192,  192,  192,
      192,  192,  192,  199,  199,  199,  199,  199,  199,  199,
      199,  199,  199,  199,  199,  199,  199,  199,  199,  199,

      199,  199,  199,  199,  199,  199,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  209,
      209,  209,  209,  209,  209,  209,  209,  209,  209,  209,
      209,  209,  209,  209,  209,  209,  209,  209,  209,  209,
      209,  209,  213,  213,  213,  213,  213,  213,  213,  213,
      213,  213,  213,  213,  213,  213,  213,  213,  213,  213,
      213,  213,  213,  213,  213,  223,  223,  223,  223,  223,
      223,  223,  223,  223,  223,  223,  223,  223,  223,  223,
      223,  223,  223,  223,  223,  223,  223,  223,  233,  758,

      757,  233,  233,  233,  233,  233,  233,  233,  233,  233,
      233,  233,  233,  233,  233,  233,  233,  233,  233,  233,
      233,  239,  239,  239,  239,  239,  239,  239,  239,  239,
      239,  239,  239,  239,  239,  239,  239,  239,  239,  239,
      239,  239,  239,  239,  241,  241,  241,  241,  241,  241,
      241,  241,  241,  241,  241,  241,  241,  241,  241,  241,
      241,  241,  241,  241,  241,  241,  241,  245,  245,  245,
      245,  245,  245,  245,  245,  245,  245,  245,  245,  245,
      245,  245,  245,  245,  245,  245,  245,  245,  245,  245,
      255,  255,  438,  255,  255,  255,  255,  255,  255,  255,

      255,  255,  255,  255,  255,  255,  255,  255,  255,  255,
      255,  255,  255,  261,  261,  755,  261,  261,  261,  261,
      261,  261,  261,  261,  261,  261,  261,  261,  261,  261,
      261,  261,  261,  754,  261,  261,  276,  276,  753,  276,
      276,  276,  276,  276,  276,  276,  276,  276,  276,  276,
      276,  276,  276,  276,  276,  276,  752,  276,  276,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,

      283,  283,  283,  283,  283,  289,  289,  289,  289,  289,
      289,  289,  289,  289,  289,  289,  289,  289,  289,  289,
      289,  289,  289,  289,  289,  289,  289,  289,  294,  294,
      751,  294,  294,  294,  294,  294,  294,  751,  294,  294,
      294,  294,  294,  294,  294,  294,  294,  294,  294,  294,
      294,  299,  299,  749,  299,  748,  299,  747,  299,  299,
      299,  299,  299,  746,  299,  745,  744,  299,  743,  299,
      299,  742,  299,  299,  306,  306,  741,  306,  306,  306,
      518,  306,  306,  306,  306,  306,  306,  306,  306,  306,
      306,  306,  306,  306,  306,  306,  306,  317,  317,  739,

      317,  317,  317,  317,  317,  317,  317,  317,  317,  317,
      317,  317,  317,  317,  317,  317,  317,  317,  317,  317,
      319,  319,  319,  319,  319,  319,  319,  319,  319,  319,
      319,  319,  319,  319,  319,  319,  319,  319,  319,  319,
      319,  319,  319,  326,  326,  438,  326,  326,  326,  326,
      326,  326,  737,  326,  326,  736,  326,  326,  600,  326,
      600,  326,  326,  326,  447,  326,  361,  361,  735,  361,
      361,  734,  361,  361,  361,  447,  361,  361,  733,  361,
      733,  447,  361,  731,  730,  361,  361,  729,  361,  372,
      372,  372,  728,  372,  727,  372,  726,  372,  725,  724,

      372,  723,  518,  722,  372,  721,  518,  372,  518,  372,
      372,  378,  378,  720,  378,  378,  378,  378,  378,  378,
      378,  378,  378,  378,  378,  378,  378,  378,  378,  378,
      378,  378,  378,  378,  379,  379,  438,  379,  379,  379,
      379,  379,  718,  379,  379,  379,  379,  379,  379,  379,
      379,  379,  379,  379,  379,  379,  379,  380,  717,  380,
      380,  380,  380,  380,  716,  715,  380,  380,  380,  380,
      380,  380,  380,  380,  714,  380,  380,  380,  380,  380,
      382,  382,  713,  382,  382,  382,  382,  382,  382,  712,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,

      382,  382,  382,  388,  388,  388,  388,  388,  388,  388,
      388,  388,  388,  388,  388,  388,  388,  388,  388,  388,
      388,  388,  388,  388,  388,  388,  392,  711,  710,  710,
      392,  392,  392,  392,  392,  708,  392,  707,  706,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  402,
      402,  402,  402,  402,  402,  402,  402,  402,  402,  402,
      402,  402,  402,  402,  402,  402,  402,  402,  402,  402,
      402,  402,  223,  223,  223,  223,  223,  223,  223,  223,
      223,  223,  223,  223,  223,  223,  223,  223,  223,  223,
      223,  223,  223,  223,  223,  233,  705,  704,  233,  233,

      233,  233,  233,  233,  233,  233,  233,  233,  233,  233,
      233,  233,  233,  233,  233,  233,  233,  233,  239,  239,
      239,  239,  239,  239,  239,  239,  239,  239,  239,  239,
      239,  239,  239,  239,  239,  239,  239,  239,  239,  239,
      239,  241,  241,  241,  241,  241,  241,  241,  241,  241,
      241,  241,  241,  241,  241,  241,  241,  241,  241,  241,
      241,  241,  241,  241,  245,  245,  245,  245,  245,  245,
      245,  245,  245,  245,  245,  245,  245,  245,  245,  245,
      245,  245,  245,  245,  245,  245,  245,  255,  255,  703,
      255,  255,  255,  255,  255,  255,  255,  255,  255,  255,

      255,  255,  255,  255,  255,  255,  255,  255,  255,  255,
      419,  419,  419,  419,  419,  419,  419,  419,  419,  419,
      419,  419,  419,  419,  419,  419,  419,  419,  419,  419,
      419,  419,  419,  428,  428,  702,  428,  428,  428,  428,
      428,  428,  428,  428,  428,  428,  428,  428,  428,  428,
      701,  428,  428,  428,  428,  428,  430,  430,  699,  430,
      430,  430,  430,  430,  430,  430,  430,  430,  430,  430,
      430,  430,  430,  430,  430,  430,  430,  430,  430,  437,
      670,  437,  437,  437,  437,  437,  437,  518,  437,  437,
      437,  437,  437,  437,  437,  437,  698,  437,  437,  437,

      437,  437,  317,  317,  697,  317,  317,  317,  317,  317,
      317,  317,  317,  317,  317,  317,  317,  317,  317,  317,
      317,  317,  317,  317,  317,  319,  319,  319,  319,  319,
      319,  319,  319,  319,  319,  319,  319,  319,  319,  319,
      319,  319,  319,  319,  319,  319,  319,  319,  361,  361,
      518,  361,  361,  518,  361,  361,  361,  518,  361,  361,
      696,  361,  695,  694,  361,  693,  692,  361,  361,  438,
      361,  372,  372,  372,  690,  372,  687,  372,  686,  372,
      685,  684,  683,  682,  681,  680,  372,  680,  678,  372,
      677,  372,  372,  478,  670,  676,  670,  675,  674,  673,

      672,  478,  671,  668,  478,  667,  666,  665,  664,  663,
      478,  379,  379,  662,  379,  379,  379,  379,  379,  661,
      379,  379,  379,  379,  379,  379,  379,  379,  379,  379,
      379,  379,  379,  379,  482,  660,  482,  482,  482,  482,
      482,  659,  658,  482,  482,  482,  482,  482,  482,  482,
      482,  657,  482,  482,  482,  482,  482,  382,  382,  656,
      382,  382,  382,  382,  382,  382,  438,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,
      388,  388,  388,  388,  388,  388,  388,  388,  388,  388,
      388,  388,  388,  388,  388,  388,  388,  388,  388,  388,

      388,  388,  388,  392,  654,  653,  607,  392,  392,  392,
      392,  392,  648,  392,  647,  646,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  402,  402,  402,  402,
      402,  402,  402,  402,  402,  402,  402,  402,  402,  402,
      402,  402,  402,  402,  402,  402,  402,  402,  402,  223,
      223,  223,  223,  223,  223,  223,  223,  223,  223,  223,
      223,  223,  223,  223,  223,  223,  223,  223,  223,  223,
      223,  223,  233,  645,  644,  233,  233,  233,  233,  233,
      233,  233,  233,  233,  233,  233,  233,  233,  233,  233,
      233,  233,  233,  233,  233,  498,  498,  643,  498,  498,

      498,  498,  498,  498,  498,  498,  498,  498,  498,  498,
      498,  498,  642,  498,  498,  498,  498,  498,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      642,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  504,  504,  504,  504,  504,  504,  504,  504,  504,
      504,  504,  504,  597,  504,  504,  504,  504,  504,  504,
      504,  504,  504,  504,  506,  640,  506,  506,  506,  506,
      506,  506,  639,  506,  506,  506,  506,  506,  506,  506,
      506,  638,  506,  506,  506,  506,  506,  531,  531,  531,
      531,  531,  531,  531,  531,  531,  531,  531,  531,  637,

      633,  531,  531,  632,  531,  531,  531,  531,  531,  531,
      543,  631,  543,  543,  543,  543,  543,  630,  629,  543,
      543,  543,  543,  543,  543,  543,  543,  628,  543,  543,
      543,  543,  543,  556,  556,  583,  556,  556,  556,  556,
      556,  556,  556,  556,  556,  556,  556,  556,  556,  556,
      626,  556,  556,  556,  556,  556,  562,  625,  562,  562,
      562,  562,  562,  562,  624,  562,  562,  562,  562,  562,
      562,  562,  562,  623,  562,  562,  562,  562,  562,  573,
      573,  573,  573,  573,  573,  573,  573,  573,  573,  622,
      573,  573,  621,  573,  573,  620,  573,  573,  573,  573,

      573,  573,  598,  619,  598,  598,  598,  598,  598,  618,
      617,  598,  598,  598,  598,  598,  598,  598,  598,  616,
      598,  598,  598,  598,  598,  613,  615,  613,  613,  613,
      613,  613,  613,  614,  613,  613,  613,  613,  613,  613,
      613,  613,  438,  613,  613,  613,  613,  613,  641,  796,
      641,  641,  641,  641,  641,  429,  429,  641,  641,  641,
      641,  641,  641,  641,  641,  612,  641,  641,  641,  641,
      641,  655,  611,  655,  655,  655,  655,  655,  655,  610,
      655,  655,  655,  655,  655,  655,  655,  655,  609,  655,
      655,  655,  655,  655,  679,  606,  679,  679,  679,  679,

      679,  605,  604,  679,  679,  679,  679,  679,  679,  679,
      679,  600,  679,  679,  679,  679,  679,  691,  599,  691,
      691,  691,  691,  691,  691,  599,  691,  691,  691,  691,
      691,  691,  691,  691,  542,  691,  691,  691,  691,  691,
      700,  700,  700,  700,  700,  700,  700,  700,  700,  700,
      700,  700,  700,  541,  700,  700,  597,  700,  700,  700,
      700,  700,  700,  709,  533,  709,  709,  709,  709,  709,
      532,  583,  709,  709,  709,  709,  709,  709,  709,  709,
      582,  709,  709,  709,  709,  709,  719,  581,  719,  719,
      719,  719,  719,  719,  580,  719,  719,  719,  719,  719,

      719,  719,  719,  579,  719,  719,  719,  719,  719,  732,
      578,  732,  732,  732,  732,  732,  577,  576,  732,  732,
      732,  732,  732,  732,  732,  732,  575,  732,  732,  732,
      732,  732,  738,  574,  738,  738,  738,  738,  738,  738,
      572,  738,  738,  738,  738,  738,  738,  738,  738,  518,
      738,  738,  738,  738,  738,  740,  740,  740,  740,  740,
      740,  740,  740,  740,  740,  571,  740,  740,  570,  740,
      740,  564,  740,  740,  740,  740,  740,  740,  750,  563,
      750,  750,  750,  750,  750,  438,  560,  750,  750,  750,
      750,  750,  750,  750,  750,  429,  750,  750,  750,  750,

      750,  756,  553,  756,  756,  756,  756,  756,  756,  552,
      756,  756,  756,  756,  756,  756,  756,  756,  551,  756,
      756,  756,  756,  756,  763,  550,  763,  763,  763,  763,
      763,  549,  548,  763,  763,  763,  763,  763,  763,  763,
      763,  547,  763,  763,  763,  763,  763,  769,  546,  769,
      769,  769,  769,  769,  769,  545,  769,  769,  769,  769,
      769,  769,  769,  769,  544,  769,  769,  769,  769,  769,
      772,  544,  772,  772,  772,  772,  772,  542,  541,  772,
      772,  772,  772,  772,  772,  772,  772,  540,  772,  772,
      772,  772,  772,  775,  536,  775,  775,  775,  775,  775,

      775,  533,  775,  775,  775,  775,  775,  775,  775,  775,
      532,  775,  775,  775,  775,  775,  777,  468,  777,  777,
      777,  777,  777,  530,  466,  777,  777,  777,  777,  777,
      777,  777,  777,  527,  777,  777,  777,  777,  777,  780,
      526,  780,  780,  780,  780,  780,  780,  525,  780,  780,
      780,  780,  780,  780,  780,  780,  524,  780,  780,  780,
      780,  780,  782,  518,  782,  782,  782,  782,  782,  523,
      522,  782,  782,  782,  782,  782,  782,  782,  782,  521,
      782,  782,  782,  782,  782,  785,  520,  785,  785,  785,
      785,  785,  785,  519,  785,  785,  785,  785,  785,  785,

      785,  785,  516,  785,  785,  785,  785,  785,  786,  512,
      786,  786,  786,  786,  786,  438,  505,  786,  786,  786,
      786,  786,  786,  786,  786,  502,  786,  786,  786,  786,
      786,  788,  429,  788,  788,  788,  788,  788,  788,  429,
      788,  788,  788,  788,  788,  788,  788,  788,  425,  788,
      788,  788,  788,  788,  789,  495,  789,  789,  789,  789,
      789,  420,  416,  789,  789,  789,  789,  789,  789,  789,
      789,  493,  789,  789,  789,  789,  789,  791,  492,  791,
      791,  791,  791,  791,  791,  491,  791,  791,  791,  791,
      791,  791,  791,  791,  410,  791,  791,  791,  791,  791,

      792,  490,  792,  792,  792,  792,  792,  407,  488,  792,
      792,  792,  792,  792,  792,  792,  792,  487,  792,  792,
      792,  792,  792,  794,  486,  794,  794,  794,  794,  794,
      794,  485,  794,  794,  794,  794,  794,  794,  794,  794,
      484,  794,  794,  794,  794,  794,  385,  483,  483,  481,
      480,  479,  376,  375,  473,  470,  469,  360,  466,  360,
      359,  463,  460,  459,  458,  457,  453,  452,  451,  449,
      448,  446,  443,  320,  318,  438,  431,  429,  310,  303,
      277,  420,  264,  262,  257,  240,  414,  413,  412,  409,
      401,  394,  385,  381,  377,  376,  375,  363,  362,  360,

      359,  320,  320,  318,  310,  303,  307,  296,  295,  278,
      277,  273,  269,  249,  266,  262,  254,  253,  252,  249,
      248,  240,  238,  237,  236,  235,  228,  222,  221,  796,
       59,   59,   59,   57,  796,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,

      796
    } ;

static const flex_int16_t yy_chk[3802] =
    {   0,
        0,    0,    0,    3,    4,    4,    4,    4,    7,    3,
        8,    7,    4,    8,    9,    9,    3,   10,   10,    4,
        5,    5,    5,    5,    6,    6,    6,    6,   12,   12,
       12,   12,   37,   15,   15,  794,   12,   15,   27,   27,
       16,   16,   28,   28,   16,   25,   25,   38,   17,   17,
       18,   18,   17,  209,   18,   25,   19,   19,   29,   29,
        5,   20,   20,   91,    6,   91,   21,   21,   15,   22,
       22,   30,   30,    5,    5,   16,  793,    6,    6,   13,
       13,   13,   13,   17,   13,   18,   31,   31,  209,   13,
       19,   19,   19,   37,   13,   20,   20,   20,  792,   13,

       21,   21,   21,   22,   22,   22,   26,   26,   38,   39,
       39,   49,   49,   39,   13,   13,   26,   23,   23,   23,
       23,   49,   23,   32,   32,   33,   33,   23,   23,   67,
       32,  791,   67,   30,   34,   34,   33,   50,   50,   33,
       13,   14,   14,   14,   14,   34,   14,   50,   34,   14,
      790,   14,   23,   23,   76,   76,   14,   24,   24,   24,
       24,   14,   24,   78,   78,   40,   40,   24,   24,   40,
       41,   41,   41,   41,   80,   80,   14,   14,   23,   42,
       42,   42,   42,  789,  102,   41,   51,   51,   51,   51,
      124,  124,   24,   24,   42,   47,   47,   66,   51,   47,

      788,   51,   14,   53,   53,  787,   47,   54,   54,   47,
      786,   43,   43,   43,   43,  102,  126,  126,   24,   35,
       35,   35,   35,   43,   35,   35,   43,  785,   35,   69,
       47,   43,   69,   85,   35,   43,   85,  139,   53,   35,
      139,   66,   54,   35,  783,   66,  308,   43,  145,   35,
       66,  145,   35,   35,  308,   35,   48,   48,   45,   45,
       48,  107,  107,  107,   45,  127,  127,   48,  147,   45,
       48,  147,   45,  129,  129,   43,   35,   45,  130,  130,
       35,   45,   35,   36,   36,   36,   36,  782,   36,   36,
      151,   48,   36,   45,   45,   85,  131,  131,   36,   52,

       52,   52,   52,   36,  133,  133,  151,   36,  134,  134,
      211,   52,  155,   36,   52,  155,   36,   36,  212,   36,
      256,   45,   63,   63,   63,   63,  256,   55,   55,   55,
       55,   95,   95,   95,   95,  187,  187,   63,  165,   55,
       36,   55,   55,  781,   36,  211,   36,   44,   44,   44,
       44,   55,  165,  212,   56,   56,   56,   56,  304,   44,
      780,  167,   44,   55,  167,  779,   56,   44,   56,   56,
      134,   44,  170,  141,  304,  170,  141,  163,   56,  141,
      163,  167,  418,   44,  322,   44,  153,  153,  153,  153,
       56,  418,  163,   95,  156,  156,  156,  156,  322,  171,

      342,  153,  171,  141,  342,  177,  141,  141,  177,  156,
      778,   44,   46,   46,   46,   46,  342,  185,  197,   46,
      185,  197,  172,  154,   46,  208,  154,   46,  208,  154,
      141,  172,   46,  222,  222,  388,   46,  162,  162,  219,
      162,  777,  219,  172,  214,  214,  214,  214,   46,   46,
       46,  175,  162,  154,  175,  188,  154,  154,  188,  223,
      223,  204,  234,  175,  204,  234,  175,  188,  226,  226,
      388,  175,  440,  204,  229,  229,   46,   93,  776,   93,
      154,  227,  227,  440,   93,   93,  231,  231,  775,  175,
      241,  241,  227,  188,   93,  390,   93,  215,  215,  215,

      215,  216,  216,  216,  216,  224,  224,  224,  224,   93,
       93,   93,  220,  333,  220,  175,  243,  243,  220,  188,
      224,  189,  189,  189,  189,  245,  245,  247,  247,  220,
      390,  189,  431,  189,  333,   93,  189,   93,  118,  431,
      118,  249,  249,  442,  250,  118,  118,  250,  263,  263,
      263,  263,  279,  279,  442,  118,  774,  118,  773,  189,
      281,  281,  283,  283,  285,  285,  288,  288,  289,  289,
      118,  118,  118,  291,  291,  293,  293,  296,  296,  296,
      296,  301,  402,  402,  301,  189,  305,  325,  312,  305,
      309,  312,  314,  309,  309,  314,  118,  316,  118,  173,

      316,  325,  305,  305,  305,  309,  250,  404,  404,  772,
      263,  173,  311,  311,  311,  311,  173,  173,  439,  173,
      329,  173,  173,  329,  173,  173,  439,  311,  354,  173,
      173,  354,  771,  173,  173,  176,  176,  176,  176,  176,
      176,  176,  176,  176,  176,  176,  176,  176,  176,  176,
      176,  176,  176,  176,  176,  176,  176,  176,  176,  176,
      176,  176,  176,  176,  176,  176,  176,  176,  176,  176,
      176,  176,  176,  176,  176,  176,  176,  176,  176,  176,
      176,  176,  176,  176,  176,  176,  176,  176,  176,  176,
      176,  176,  176,  176,  176,  176,  176,  176,  176,  176,

      176,  176,  300,  320,  313,  300,  320,  313,  300,  770,
      313,  315,  315,  315,  315,  769,  321,  321,  320,  321,
      327,  328,  338,  327,  323,  338,  315,  323,  406,  406,
      328,  321,  300,  471,  313,  300,  300,  313,  313,  323,
      327,  353,  328,  347,  353,  358,  347,  363,  358,  443,
      338,  423,  423,  363,  471,  347,  445,  358,  347,  300,
      443,  313,  363,  347,  371,  371,  371,  371,  365,  441,
      383,  445,  365,  383,  363,  427,  338,  441,  427,  353,
      444,  347,  383,  393,  393,  393,  393,  424,  424,  424,
      424,  427,  427,  427,  444,  768,  494,  500,  365,  477,

      477,  477,  477,  494,  500,  353,  766,  347,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  365,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  366,  765,  449,  366,  367,
      367,  367,  367,  370,  370,  370,  370,  366,  472,  367,
      434,  367,  449,  434,  463,  370,  467,  463,  497,  467,

      764,  497,  505,  497,  534,  434,  463,  529,  467,  472,
      505,  510,  510,  366,  510,  528,  535,  367,  528,  534,
      560,  370,  502,  502,  502,  502,  510,  528,  560,  537,
      528,  535,  537,  529,  502,  528,  550,  550,  763,  366,
      762,  537,  652,  367,  761,  652,  760,  370,  447,  447,
      447,  447,  447,  447,  447,  447,  447,  447,  447,  447,
      447,  447,  447,  447,  447,  447,  447,  447,  447,  447,
      447,  447,  447,  447,  447,  447,  447,  447,  447,  447,
      447,  447,  447,  447,  447,  447,  447,  447,  447,  447,
      447,  447,  447,  447,  447,  447,  447,  447,  447,  447,

      447,  447,  447,  447,  447,  447,  447,  447,  447,  447,
      447,  447,  447,  447,  447,  461,  464,  475,  461,  464,
      475,  476,  476,  476,  476,  509,  546,  461,  509,  475,
      461,  569,  546,  476,  569,  461,  759,  584,  538,  538,
      538,  538,  758,  546,  757,  509,  569,  609,  565,  509,
      538,  565,  584,  461,  464,  475,  609,  536,  536,  476,
      756,  509,  536,  536,  688,  536,  536,  688,  568,  568,
      536,  568,  565,  536,  536,  536,  538,  755,  591,  461,
      464,  475,  591,  754,  565,  476,  539,  539,  539,  539,
      558,  558,  558,  558,  591,  596,  596,  596,  596,  630,

      610,  651,  538,  610,  651,  689,  753,  596,  689,  752,
      751,  750,  749,  748,  630,  747,  746,  745,  744,  743,
      742,  610,  651,  797,  797,  797,  797,  797,  797,  797,
      797,  797,  797,  797,  797,  797,  797,  797,  797,  797,
      797,  797,  797,  797,  797,  797,  798,  798,  798,  798,
      798,  798,  798,  798,  798,  798,  798,  798,  798,  798,
      798,  798,  798,  798,  798,  798,  798,  798,  798,  799,
      799,  799,  799,  799,  799,  799,  799,  799,  799,  799,
      799,  799,  799,  799,  799,  799,  799,  799,  799,  799,
      799,  799,  800,  800,  800,  800,  800,  800,  800,  800,

      800,  800,  800,  800,  800,  800,  800,  800,  800,  800,
      800,  800,  800,  800,  800,  801,  801,  801,  801,  801,
      801,  801,  801,  801,  801,  801,  801,  801,  801,  801,
      801,  801,  801,  801,  801,  801,  801,  801,  802,  802,
      802,  802,  802,  802,  802,  802,  802,  802,  802,  802,
      802,  802,  802,  802,  802,  802,  802,  802,  802,  802,
      802,  803,  803,  803,  803,  803,  803,  803,  803,  803,
      803,  803,  803,  803,  803,  803,  803,  803,  803,  803,
      803,  803,  803,  803,  804,  804,  804,  804,  804,  804,
      804,  804,  804,  804,  804,  804,  804,  804,  804,  804,

      804,  804,  804,  804,  804,  804,  804,  805,  805,  805,
      805,  805,  805,  805,  805,  805,  805,  805,  805,  805,
      805,  805,  805,  805,  805,  805,  805,  805,  805,  805,
      806,  806,  806,  806,  806,  806,  806,  806,  806,  806,
      806,  806,  806,  806,  806,  806,  806,  806,  806,  806,
      806,  806,  806,  807,  807,  807,  807,  807,  807,  807,
      807,  807,  807,  807,  807,  807,  807,  807,  807,  807,
      807,  807,  807,  807,  807,  807,  808,  808,  808,  808,
      808,  808,  808,  808,  808,  808,  808,  808,  808,  808,
      808,  808,  808,  808,  808,  808,  808,  808,  808,  809,

      809,  809,  809,  809,  809,  809,  809,  809,  809,  809,
      809,  809,  809,  809,  809,  809,  809,  809,  809,  809,
      809,  809,  810,  810,  810,  810,  810,  810,  810,  810,
      810,  810,  810,  810,  810,  810,  810,  810,  810,  810,
      810,  810,  810,  810,  810,  811,  811,  811,  811,  811,
      811,  811,  811,  811,  811,  811,  811,  811,  811,  811,
      811,  811,  811,  811,  811,  811,  811,  811,  812,  812,
      812,  812,  812,  812,  812,  812,  812,  812,  812,  812,
      812,  812,  812,  812,  812,  812,  812,  812,  812,  812,
      812,  813,  813,  813,  813,  813,  813,  813,  813,  813,

      813,  813,  813,  813,  813,  813,  813,  813,  813,  813,
      813,  813,  813,  813,  814,  814,  814,  814,  814,  814,
      814,  814,  814,  814,  814,  814,  814,  814,  814,  814,
      814,  814,  814,  814,  814,  814,  814,  815,  815,  815,
      815,  815,  815,  815,  815,  815,  815,  815,  815,  815,
      815,  815,  815,  815,  815,  815,  815,  815,  815,  815,
      816,  816,  816,  816,  816,  816,  816,  816,  816,  816,
      816,  816,  816,  816,  816,  816,  816,  816,  816,  816,
      816,  816,  816,  817,  817,  817,  817,  817,  817,  817,
      817,  817,  817,  817,  817,  817,  817,  817,  817,  817,

      817,  817,  817,  817,  817,  817,  818,  818,  818,  818,
      818,  818,  818,  818,  818,  818,  818,  818,  818,  818,
      818,  818,  818,  818,  818,  818,  818,  818,  818,  819,
      819,  819,  819,  819,  819,  819,  819,  819,  819,  819,
      819,  819,  819,  819,  819,  819,  819,  819,  819,  819,
      819,  819,  820,  820,  820,  820,  820,  820,  820,  820,
      820,  820,  820,  820,  820,  820,  820,  820,  820,  820,
      820,  820,  820,  820,  820,  821,  821,  821,  821,  821,
      821,  821,  821,  821,  821,  821,  821,  821,  821,  821,
      821,  821,  821,  821,  821,  821,  821,  821,  822,  741,

      739,  822,  822,  822,  822,  822,  822,  822,  822,  822,
      822,  822,  822,  822,  822,  822,  822,  822,  822,  822,
      822,  823,  823,  823,  823,  823,  823,  823,  823,  823,
      823,  823,  823,  823,  823,  823,  823,  823,  823,  823,
      823,  823,  823,  823,  824,  824,  824,  824,  824,  824,
      824,  824,  824,  824,  824,  824,  824,  824,  824,  824,
      824,  824,  824,  824,  824,  824,  824,  825,  825,  825,
      825,  825,  825,  825,  825,  825,  825,  825,  825,  825,
      825,  825,  825,  825,  825,  825,  825,  825,  825,  825,
      826,  826,  738,  826,  826,  826,  826,  826,  826,  826,

      826,  826,  826,  826,  826,  826,  826,  826,  826,  826,
      826,  826,  826,  827,  827,  737,  827,  827,  827,  827,
      827,  827,  827,  827,  827,  827,  827,  827,  827,  827,
      827,  827,  827,  736,  827,  827,  828,  828,  735,  828,
      828,  828,  828,  828,  828,  828,  828,  828,  828,  828,
      828,  828,  828,  828,  828,  828,  734,  828,  828,  829,
      829,  829,  829,  829,  829,  829,  829,  829,  829,  829,
      829,  829,  829,  829,  829,  829,  829,  829,  829,  829,
      829,  829,  830,  830,  830,  830,  830,  830,  830,  830,
      830,  830,  830,  830,  830,  830,  830,  830,  830,  830,

      830,  830,  830,  830,  830,  831,  831,  831,  831,  831,
      831,  831,  831,  831,  831,  831,  831,  831,  831,  831,
      831,  831,  831,  831,  831,  831,  831,  831,  832,  832,
      733,  832,  832,  832,  832,  832,  832,  732,  832,  832,
      832,  832,  832,  832,  832,  832,  832,  832,  832,  832,
      832,  833,  833,  731,  833,  730,  833,  729,  833,  833,
      833,  833,  833,  728,  833,  727,  726,  833,  725,  833,
      833,  724,  833,  833,  834,  834,  723,  834,  834,  834,
      721,  834,  834,  834,  834,  834,  834,  834,  834,  834,
      834,  834,  834,  834,  834,  834,  834,  835,  835,  720,

      835,  835,  835,  835,  835,  835,  835,  835,  835,  835,
      835,  835,  835,  835,  835,  835,  835,  835,  835,  835,
      836,  836,  836,  836,  836,  836,  836,  836,  836,  836,
      836,  836,  836,  836,  836,  836,  836,  836,  836,  836,
      836,  836,  836,  837,  837,  719,  837,  837,  837,  837,
      837,  837,  717,  837,  837,  716,  837,  837,  715,  837,
      714,  837,  837,  837,  859,  837,  838,  838,  713,  838,
      838,  712,  838,  838,  838,  859,  838,  838,  710,  838,
      709,  859,  838,  708,  707,  838,  838,  706,  838,  839,
      839,  839,  705,  839,  704,  839,  703,  839,  702,  701,

      839,  699,  698,  697,  839,  696,  695,  839,  694,  839,
      839,  840,  840,  693,  840,  840,  840,  840,  840,  840,
      840,  840,  840,  840,  840,  840,  840,  840,  840,  840,
      840,  840,  840,  840,  841,  841,  691,  841,  841,  841,
      841,  841,  690,  841,  841,  841,  841,  841,  841,  841,
      841,  841,  841,  841,  841,  841,  841,  842,  687,  842,
      842,  842,  842,  842,  686,  685,  842,  842,  842,  842,
      842,  842,  842,  842,  684,  842,  842,  842,  842,  842,
      843,  843,  683,  843,  843,  843,  843,  843,  843,  682,
      843,  843,  843,  843,  843,  843,  843,  843,  843,  843,

      843,  843,  843,  844,  844,  844,  844,  844,  844,  844,
      844,  844,  844,  844,  844,  844,  844,  844,  844,  844,
      844,  844,  844,  844,  844,  844,  845,  681,  680,  679,
      845,  845,  845,  845,  845,  678,  845,  677,  676,  845,
      845,  845,  845,  845,  845,  845,  845,  845,  845,  846,
      846,  846,  846,  846,  846,  846,  846,  846,  846,  846,
      846,  846,  846,  846,  846,  846,  846,  846,  846,  846,
      846,  846,  847,  847,  847,  847,  847,  847,  847,  847,
      847,  847,  847,  847,  847,  847,  847,  847,  847,  847,
      847,  847,  847,  847,  847,  848,  675,  674,  848,  848,

      848,  848,  848,  848,  848,  848,  848,  848,  848,  848,
      848,  848,  848,  848,  848,  848,  848,  848,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  850,  850,  850,  850,  850,  850,  850,  850,  850,
      850,  850,  850,  850,  850,  850,  850,  850,  850,  850,
      850,  850,  850,  850,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  852,  852,  673,
      852,  852,  852,  852,  852,  852,  852,  852,  852,  852,

      852,  852,  852,  852,  852,  852,  852,  852,  852,  852,
      853,  853,  853,  853,  853,  853,  853,  853,  853,  853,
      853,  853,  853,  853,  853,  853,  853,  853,  853,  853,
      853,  853,  853,  854,  854,  672,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      671,  854,  854,  854,  854,  854,  855,  855,  669,  855,
      855,  855,  855,  855,  855,  855,  855,  855,  855,  855,
      855,  855,  855,  855,  855,  855,  855,  855,  855,  856,
      668,  856,  856,  856,  856,  856,  856,  666,  856,  856,
      856,  856,  856,  856,  856,  856,  665,  856,  856,  856,

      856,  856,  857,  857,  664,  857,  857,  857,  857,  857,
      857,  857,  857,  857,  857,  857,  857,  857,  857,  857,
      857,  857,  857,  857,  857,  858,  858,  858,  858,  858,
      858,  858,  858,  858,  858,  858,  858,  858,  858,  858,
      858,  858,  858,  858,  858,  858,  858,  858,  860,  860,
      663,  860,  860,  662,  860,  860,  860,  661,  860,  860,
      660,  860,  659,  658,  860,  657,  656,  860,  860,  655,
      860,  861,  861,  861,  653,  861,  650,  861,  649,  861,
      647,  646,  645,  644,  643,  642,  861,  641,  640,  861,
      639,  861,  861,  862,  638,  637,  636,  635,  634,  633,

      632,  862,  631,  629,  862,  627,  626,  625,  624,  623,
      862,  863,  863,  622,  863,  863,  863,  863,  863,  621,
      863,  863,  863,  863,  863,  863,  863,  863,  863,  863,
      863,  863,  863,  863,  864,  620,  864,  864,  864,  864,
      864,  619,  618,  864,  864,  864,  864,  864,  864,  864,
      864,  617,  864,  864,  864,  864,  864,  865,  865,  614,
      865,  865,  865,  865,  865,  865,  613,  865,  865,  865,
      865,  865,  865,  865,  865,  865,  865,  865,  865,  865,
      866,  866,  866,  866,  866,  866,  866,  866,  866,  866,
      866,  866,  866,  866,  866,  866,  866,  866,  866,  866,

      866,  866,  866,  867,  612,  611,  608,  867,  867,  867,
      867,  867,  606,  867,  605,  604,  867,  867,  867,  867,
      867,  867,  867,  867,  867,  867,  868,  868,  868,  868,
      868,  868,  868,  868,  868,  868,  868,  868,  868,  868,
      868,  868,  868,  868,  868,  868,  868,  868,  868,  869,
      869,  869,  869,  869,  869,  869,  869,  869,  869,  869,
      869,  869,  869,  869,  869,  869,  869,  869,  869,  869,
      869,  869,  870,  603,  602,  870,  870,  870,  870,  870,
      870,  870,  870,  870,  870,  870,  870,  870,  870,  870,
      870,  870,  870,  870,  870,  871,  871,  601,  871,  871,

      871,  871,  871,  871,  871,  871,  871,  871,  871,  871,
      871,  871,  599,  871,  871,  871,  871,  871,  872,  872,
      872,  872,  872,  872,  872,  872,  872,  872,  872,  872,
      598,  872,  872,  872,  872,  872,  872,  872,  872,  872,
      872,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  597,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  874,  595,  874,  874,  874,  874,
      874,  874,  594,  874,  874,  874,  874,  874,  874,  874,
      874,  593,  874,  874,  874,  874,  874,  875,  875,  875,
      875,  875,  875,  875,  875,  875,  875,  875,  875,  592,

      590,  875,  875,  589,  875,  875,  875,  875,  875,  875,
      876,  588,  876,  876,  876,  876,  876,  587,  586,  876,
      876,  876,  876,  876,  876,  876,  876,  585,  876,  876,
      876,  876,  876,  877,  877,  583,  877,  877,  877,  877,
      877,  877,  877,  877,  877,  877,  877,  877,  877,  877,
      582,  877,  877,  877,  877,  877,  878,  581,  878,  878,
      878,  878,  878,  878,  580,  878,  878,  878,  878,  878,
      878,  878,  878,  579,  878,  878,  878,  878,  878,  879,
      879,  879,  879,  879,  879,  879,  879,  879,  879,  578,
      879,  879,  577,  879,  879,  576,  879,  879,  879,  879,

      879,  879,  880,  575,  880,  880,  880,  880,  880,  574,
      572,  880,  880,  880,  880,  880,  880,  880,  880,  571,
      880,  880,  880,  880,  880,  881,  567,  881,  881,  881,
      881,  881,  881,  563,  881,  881,  881,  881,  881,  881,
      881,  881,  562,  881,  881,  881,  881,  881,  882,  561,
      882,  882,  882,  882,  882,  557,  556,  882,  882,  882,
      882,  882,  882,  882,  882,  554,  882,  882,  882,  882,
      882,  883,  553,  883,  883,  883,  883,  883,  883,  552,
      883,  883,  883,  883,  883,  883,  883,  883,  551,  883,
      883,  883,  883,  883,  884,  549,  884,  884,  884,  884,

      884,  548,  547,  884,  884,  884,  884,  884,  884,  884,
      884,  545,  884,  884,  884,  884,  884,  885,  544,  885,
      885,  885,  885,  885,  885,  543,  885,  885,  885,  885,
      885,  885,  885,  885,  542,  885,  885,  885,  885,  885,
      886,  886,  886,  886,  886,  886,  886,  886,  886,  886,
      886,  886,  886,  541,  886,  886,  540,  886,  886,  886,
      886,  886,  886,  887,  533,  887,  887,  887,  887,  887,
      532,  530,  887,  887,  887,  887,  887,  887,  887,  887,
      527,  887,  887,  887,  887,  887,  888,  526,  888,  888,
      888,  888,  888,  888,  525,  888,  888,  888,  888,  888,

      888,  888,  888,  524,  888,  888,  888,  888,  888,  889,
      523,  889,  889,  889,  889,  889,  522,  521,  889,  889,
      889,  889,  889,  889,  889,  889,  520,  889,  889,  889,
      889,  889,  890,  519,  890,  890,  890,  890,  890,  890,
      517,  890,  890,  890,  890,  890,  890,  890,  890,  516,
      890,  890,  890,  890,  890,  891,  891,  891,  891,  891,
      891,  891,  891,  891,  891,  512,  891,  891,  511,  891,
      891,  508,  891,  891,  891,  891,  891,  891,  892,  507,
      892,  892,  892,  892,  892,  506,  503,  892,  892,  892,
      892,  892,  892,  892,  892,  498,  892,  892,  892,  892,

      892,  893,  493,  893,  893,  893,  893,  893,  893,  492,
      893,  893,  893,  893,  893,  893,  893,  893,  491,  893,
      893,  893,  893,  893,  894,  490,  894,  894,  894,  894,
      894,  488,  487,  894,  894,  894,  894,  894,  894,  894,
      894,  486,  894,  894,  894,  894,  894,  895,  485,  895,
      895,  895,  895,  895,  895,  484,  895,  895,  895,  895,
      895,  895,  895,  895,  483,  895,  895,  895,  895,  895,
      896,  482,  896,  896,  896,  896,  896,  481,  480,  896,
      896,  896,  896,  896,  896,  896,  896,  479,  896,  896,
      896,  896,  896,  897,  473,  897,  897,  897,  897,  897,

      897,  470,  897,  897,  897,  897,  897,  897,  897,  897,
      469,  897,  897,  897,  897,  897,  898,  468,  898,  898,
      898,  898,  898,  466,  465,  898,  898,  898,  898,  898,
      898,  898,  898,  460,  898,  898,  898,  898,  898,  899,
      459,  899,  899,  899,  899,  899,  899,  458,  899,  899,
      899,  899,  899,  899,  899,  899,  457,  899,  899,  899,
      899,  899,  900,  456,  900,  900,  900,  900,  900,  455,
      454,  900,  900,  900,  900,  900,  900,  900,  900,  453,
      900,  900,  900,  900,  900,  901,  452,  901,  901,  901,
      901,  901,  901,  451,  901,  901,  901,  901,  901,  901,

      901,  901,  448,  901,  901,  901,  901,  901,  902,  446,
      902,  902,  902,  902,  902,  437,  436,  902,  902,  902,
      902,  902,  902,  902,  902,  433,  902,  902,  902,  902,
      902,  903,  430,  903,  903,  903,  903,  903,  903,  428,
      903,  903,  903,  903,  903,  903,  903,  903,  426,  903,
      903,  903,  903,  903,  904,  420,  904,  904,  904,  904,
      904,  419,  417,  904,  904,  904,  904,  904,  904,  904,
      904,  414,  904,  904,  904,  904,  904,  905,  413,  905,
      905,  905,  905,  905,  905,  412,  905,  905,  905,  905,
      905,  905,  905,  905,  411,  905,  905,  905,  905,  905,

      906,  409,  906,  906,  906,  906,  906,  408,  401,  906,
      906,  906,  906,  906,  906,  906,  906,  400,  906,  906,
      906,  906,  906,  907,  399,  907,  907,  907,  907,  907,
      907,  398,  907,  907,  907,  907,  907,  907,  907,  907,
      397,  907,  907,  907,  907,  907,  384,  381,  380,  376,
      375,  374,  369,  368,  364,  360,  359,  357,  356,  351,
      350,  349,  346,  345,  344,  343,  341,  340,  339,  337,
      336,  334,  324,  319,  317,  310,  307,  306,  303,  302,
      276,  269,  265,  261,  255,  239,  238,  237,  236,  230,
      221,  217,  207,  202,  196,  191,  190,  186,  184,  179,

      178,  164,  161,  160,  150,  149,  146,  138,  137,  122,
      119,  113,  106,   98,   97,   94,   90,   89,   87,   83,
       82,   75,   74,   73,   72,   71,   65,   61,   60,   57,
       11,    2,    1,  796,  796,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,
      796,  796,  796,  796,  796,  796,  796,  796,  796,  796,

      796
    } ;

#define YY_TRAILING_MASK 0x2000
#define YY_TRAILING_HEAD_MASK 0x4000
#define REJECT \
{ \
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */ \
yy_cp = yyg->yy_full_match; /* restore poss. backed-over text */ \
yyg->yy_lp = yyg->yy_full_lp; /* restore orig. accepting pos. */ \
yyg->yy_state_ptr = yyg->yy_full_state; /* restore orig. state */ \
yy_current_state = *yyg->yy_state_ptr; /* restore curr. state */ \
++yyg->yy_lp; \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
/*****************************************************************************
 *
 * Copyright (C) 1997-2021 by Dimitri van Heesch.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation under the terms of the GNU General Public License is hereby
 * granted. No representations are made about the suitability of this software
 * for any purpose. It is provided "as is" without express or implied warranty.
 * See the GNU General Public License for more details.
 *
 * Documents produced by Doxygen are derivative works derived from the
 * input used in their production; they are not affected by this license.
 *
 */

#line 30 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"

/*
 *      includes
 */

#include <algorithm>
#include <vector>
#include <utility>

#include <stdio.h>
#include <stdlib.h>
#include <assert.h>
#include <ctype.h>

#include "config.h"
#include "lexscanner.h"
#include "entry.h"
#include "message.h"
#include "util.h"
#include "scanner.h"
#include "debug.h"

#define YY_NO_INPUT 1
#define YY_NO_UNISTD_H 1

#define repeatChar(chr, cnt) DString().fill(chr,cnt)

struct lexscannerYY_state
{
  COutlineParser   cOutlineParser;
  const char *     inputString = nullptr;
  int              inputPosition = 0;

  int              lastContext = 0;
  int              lastCContext = 0;
  int              lastStringContext = 0;
  int              docBlockContext  = 0;
  int              lastPreLineCtrlContext = 0;
  int              lastRawStringContext = 0;
  int              curlyCount = 0;

  bool             insideCode = false;
  DString         delimiter;
  DString         docBlockName;
  size_t           fencedSize = 0;
  bool             nestedComment = false;

  DString         prefix = "yy";
  bool             reentrant = false;
  bool             bison_bridge = false;
  bool             bison_locations = false;
  DString         cCodeBuffer;
  int              roundCount = 0;

  DString         fileName;
  ClangTUParser   *clangParser = nullptr;

  std::shared_ptr<Entry> current;
  std::shared_ptr<Entry> current_root;
  SrcLangExt language;
};

[[maybe_unused]] static const char *stateToString(int state);
//-----------------------------------------------------------------------------

// forward declarations for stateful functions
static void handleCCode(yyscan_t yyscanner);
static int yyread(yyscan_t yyscanner,char *buf,int max_size);

/* ----------------------------------------------------------------- */
#undef  YY_INPUT
#define YY_INPUT(buf,result,max_size) result=yyread(yyscanner,buf,max_size);

// otherwise the filename would be the name of the converted file (*.cpp instead of *.l)
static inline const char *getLexerFILE() {return __FILE__;}
#include "doxygen_lex.h"

#line 1949 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner_intermediate.cpp"
#line 142 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
  /* no comment start / end signs inside square brackets */
  // C start comment
  // C end comment
  // Cpp comment
  // doxygen start comment
  // Optional any character
  // Optional all but newline



























#line 1985 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner_intermediate.cpp"

#define INITIAL 0
#define DefSection 1
#define Option 2
#define OptPrefix 3
#define DefSectionLine 4
#define RulesSectionInit 5
#define RulesPattern 6
#define RulesDouble 7
#define RulesRoundDouble 8
#define RulesSquare 9
#define RulesRoundSquare 10
#define RulesRound 11
#define RulesRoundQuest 12
#define UserSection 13
#define TopSection 14
#define LiteralSection 15
#define COMMENT 16
#define SkipCurly 17
#define SkipCurlyEndDoc 18
#define PreLineCtrl 19
#define DocLine 20
#define DocBlock 21
#define DocCopyBlock 22
#define SkipString 23
#define RawString 24
#define SkipComment 25
#define SkipCxxComment 26
#define Comment 27

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#define YY_EXTRA_TYPE struct lexscannerYY_state *

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    yy_state_type *yy_state_buf;
    yy_state_type *yy_state_ptr;
    char *yy_full_match;
    int yy_lp;

    /* These are only needed for trailing context rules,
     * but there's no conditional variable for that yet. */
    int yy_looking_for_trail_begin;
    int yy_full_lp;
    int *yy_full_state;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  , yyscan_t yyscanner);
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (yyscan_t yyscanner);

#define YY_DECL int yylex (yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! yyg->yy_state_buf )
            yyg->yy_state_buf = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  , yyscanner);
            if ( ! yyg->yy_state_buf )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
#line 189 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"


#line 2293 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner_intermediate.cpp"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
		yy_current_state += YY_AT_BOL();

		yyg->yy_state_ptr = yyg->yy_state_buf;
		*yyg->yy_state_ptr++ = yy_current_state;

yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 797 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			*yyg->yy_state_ptr++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_current_state != 796 );

yy_find_action:
		yy_current_state = *--yyg->yy_state_ptr;
		yyg->yy_lp = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( yyg->yy_lp && yyg->yy_lp < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[yyg->yy_lp];
				if ( yy_act & YY_TRAILING_HEAD_MASK ||
				     yyg->yy_looking_for_trail_begin )
					{
					if ( yy_act == yyg->yy_looking_for_trail_begin )
						{
						yyg->yy_looking_for_trail_begin = 0;
						yy_act &= ~YY_TRAILING_HEAD_MASK;
						break;
						}
					}
				else if ( yy_act & YY_TRAILING_MASK )
					{
					yyg->yy_looking_for_trail_begin = yy_act & ~YY_TRAILING_MASK;
					yyg->yy_looking_for_trail_begin |= YY_TRAILING_HEAD_MASK;
					yyg->yy_full_match = yy_cp;
					yyg->yy_full_state = yyg->yy_state_ptr;
					yyg->yy_full_lp = yyg->yy_lp;
					}
				else
					{
					yyg->yy_full_match = yy_cp;
					yyg->yy_full_state = yyg->yy_state_ptr;
					yyg->yy_full_lp = yyg->yy_lp;
					break;
					}
				++yyg->yy_lp;
				goto find_rule;
				}
			--yy_cp;
			yy_current_state = *--yyg->yy_state_ptr;
			yyg->yy_lp = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
YY_RULE_SETUP
#line 191 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"

	YY_BREAK
case 2:
YY_RULE_SETUP
#line 192 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           BEGIN (Option);
                         }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 195 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           BEGIN (OptPrefix);
                         }
	YY_BREAK
case 4:
/* rule 4 can match eol */
YY_RULE_SETUP
#line 198 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->prefix = yytext;
                           yyextra->prefix = yyextra->prefix.mid(1,yyleng-2);
                           BEGIN (Option);
                         }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 203 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra-> reentrant = true;
                         }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 206 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra-> bison_bridge = true;
                         }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 209 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra-> bison_bridge = true;
                           yyextra-> bison_locations = true;
                         }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 213 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"

	YY_BREAK
case 9:
YY_RULE_SETUP
#line 214 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"

	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 215 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += yytext;
                           BEGIN (DefSection);
                         }
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 219 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           {
                             bool fill = false;
                             yyextra->cCodeBuffer += "int " + yyextra->prefix + "lex (";
                             if (yyextra->bison_bridge )
                             {
                               if (fill) yyextra->cCodeBuffer += ",";
                               yyextra->cCodeBuffer += "YYSTYPE * yylval_param";
                               fill = true;
                             }
                             if (yyextra->bison_locations)
                             {
                               if (fill) yyextra->cCodeBuffer += ",";
                               yyextra->cCodeBuffer += "YYLTYPE * yylloc_param";
                               fill = true;
                             }
                             if (yyextra->reentrant)
                             {
                               if (fill) yyextra->cCodeBuffer += ",";
                               yyextra->cCodeBuffer += "yyscan_t yyscanner";
                               fill = true;
                             }
                             if (!yyextra->bison_bridge && !yyextra->bison_locations && !yyextra->reentrant)
                             {
                               yyextra->cCodeBuffer += "void";
                             }
                             yyextra->cCodeBuffer += ") {\n";
                           }
                           BEGIN (RulesSectionInit);
                         }
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 249 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += "\n";
                           yyextra->lastContext = YY_START;
                           BEGIN (TopSection);
                         }
	YY_BREAK
case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
#line 254 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += "\n";
                           yyextra->lastContext = YY_START;
                           BEGIN (LiteralSection);
                         }
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 259 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += "\n";
                           BEGIN( yyextra->lastContext ) ;
                         }
	YY_BREAK
case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
#line 263 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += yytext;
                         }
	YY_BREAK
case 16:
/* rule 16 can match eol */
YY_RULE_SETUP
#line 266 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += "\n";
                           BEGIN( yyextra->lastContext ) ;
                         }
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 270 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += yytext;
                         }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 273 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           BEGIN(DefSectionLine);
                         }
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 276 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += yytext;
                         }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 279 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += yytext;
                           yyextra->lastContext = YY_START;
                           BEGIN(COMMENT);
                         }
	YY_BREAK
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
#line 284 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer+=yytext;
                           BEGIN(yyextra->lastContext);
                         }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 288 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer+=yytext;
                           BEGIN(yyextra->lastContext);
                         }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 292 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += yytext;
                         }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 295 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += yytext;
                         }
	YY_BREAK
case 25:
/* rule 25 can match eol */
YY_RULE_SETUP
#line 298 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += yytext;
                         }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 301 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += yytext;
                         }
	YY_BREAK
case 27:
/* rule 27 can match eol */
YY_RULE_SETUP
#line 304 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += "\n";
                         }
	YY_BREAK
case 28:
/* rule 28 can match eol */
YY_RULE_SETUP
#line 307 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += yytext;
                         }
	YY_BREAK
case 29:
/* rule 29 can match eol */
YY_RULE_SETUP
#line 310 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += "\n";
                           BEGIN(DefSection);
                         }
	YY_BREAK
case 30:
/* rule 30 can match eol */
YY_RULE_SETUP
#line 314 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += "}\n";
                           BEGIN (UserSection);
                         }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 318 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           unput(*yytext);
                           BEGIN(RulesPattern);
                         }
	YY_BREAK
case 32:
/* rule 32 can match eol */
YY_RULE_SETUP
#line 322 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += yytext;
                         }
	YY_BREAK
case 33:
/* rule 33 can match eol */
YY_RULE_SETUP
#line 325 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += yytext;
                         }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 328 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                         }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 331 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                         }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 334 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                         }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 337 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                         }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 340 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                           yyextra->lastContext = YY_START;
                           BEGIN(RulesDouble);
                        }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 345 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                        }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 348 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                        }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 351 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                           BEGIN( yyextra->lastContext ) ;
                        }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 355 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                           BEGIN(RulesRound) ;
                        }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 359 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                        }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 362 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                           yyextra->lastContext = YY_START;
                           BEGIN(RulesSquare);
                        }
	YY_BREAK
case 45:
/* rule 45 can match eol */
YY_RULE_SETUP
#line 367 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                        }
	YY_BREAK
case 46:
#line 371 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
case 47:
YY_RULE_SETUP
#line 371 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                        }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 374 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                           BEGIN(RulesPattern);
                        }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 378 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                           BEGIN(RulesRound) ;
                        }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 382 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                        }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 385 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                        }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 388 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                           yyextra->lastContext = YY_START;
                           BEGIN(RulesRoundQuest);
                         }
	YY_BREAK
case 53:
/* rule 53 can match eol */
YY_RULE_SETUP
#line 393 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += "\n";
                         }
	YY_BREAK
case 54:
/* rule 54 can match eol */
YY_RULE_SETUP
#line 396 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                         }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 399 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                           BEGIN(yyextra->lastContext);
                         }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 403 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->roundCount++;
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                           yyextra->lastContext = YY_START;
                           BEGIN(RulesRound);
                        }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 409 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                        }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 412 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                           BEGIN(RulesRoundSquare);
                        }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 416 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                           BEGIN(RulesRoundDouble);
                        }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 420 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                        }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 423 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->roundCount++;
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                        }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 427 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->roundCount--;
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                           if (!yyextra->roundCount) BEGIN( yyextra->lastContext ) ;
                        }
	YY_BREAK
case 63:
/* rule 63 can match eol */
YY_RULE_SETUP
#line 432 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += "\n";
                        }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 435 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                        }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 438 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                        }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 441 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                           yyextra->curlyCount = 0;
                           BEGIN(SkipCurly);
                         }
	YY_BREAK
case 67:
/* rule 67 can match eol */
YY_RULE_SETUP
#line 446 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += "\n";
                         }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 449 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                         }
	YY_BREAK
case 69:
/* rule 69 can match eol */
YY_RULE_SETUP
#line 452 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           unput(*yytext);
                           yyextra->curlyCount = 0;
                           BEGIN(SkipCurly);
                         }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 457 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                         }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 460 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += yytext;
                           yyextra->lastContext = YY_START;
                           BEGIN(COMMENT);
                         }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 465 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                           yyextra->cCodeBuffer += repeatChar(' ', yyleng);
                         }
	YY_BREAK
case 73:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 468 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ /* line control directive */
                            yyextra->cCodeBuffer += yytext;
                            yyextra->lastPreLineCtrlContext = YY_START;
                            BEGIN( PreLineCtrl );
                          }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 473 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 476 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 76:
/* rule 76 can match eol */
YY_RULE_SETUP
#line 479 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                            BEGIN( yyextra->lastPreLineCtrlContext );
                          }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 483 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                                          ++yyextra->curlyCount ;
                          }
	YY_BREAK
case 78:
/* rule 78 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 1);
yyg->yy_c_buf_p = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
#line 488 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
case 79:
/* rule 79 can match eol */
YY_RULE_SETUP
#line 488 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                            if( yyextra->curlyCount )
                            {
                              --yyextra->curlyCount ;
                            }
                          }
	YY_BREAK
case 80:
/* rule 80 can match eol */
YY_RULE_SETUP
#line 495 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                            if ( yyextra->curlyCount )
                            {
                              --yyextra->curlyCount ;
                            }
                            else
                            {
                              yyextra->docBlockContext   = SkipCurlyEndDoc;
                              if (yytext[yyleng-3]=='/')
                              {
                                BEGIN( DocLine );
                              }
                              else
                              {
                                BEGIN( DocBlock );
                              }
                            }
                          }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 514 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                            yyextra->lastStringContext=SkipCurly;
                            BEGIN( SkipString );
                          }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 519 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                            yyextra->lastPreLineCtrlContext = YY_START;
                            BEGIN( PreLineCtrl );
                          }
	YY_BREAK
case 83:
/* rule 83 can match eol */
YY_RULE_SETUP
#line 524 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            char *p=yytext;
                            while (*p && disspace(*p)) p++;
                            yyextra->delimiter = extractBeginRawStringDelimiter(p);
                            yyextra->lastRawStringContext = YY_START;
                            yyextra->cCodeBuffer += yytext;
                            BEGIN(RawString);
                          }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 532 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 535 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                                          yyextra->lastCContext = YY_START;
                                          BEGIN(SkipComment);
                          }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 540 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                                          yyextra->lastCContext = YY_START;
                                          BEGIN(SkipCxxComment);
                          }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 545 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 548 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 551 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 554 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                            yyextra->docBlockContext   = YY_START;
                            BEGIN( DocBlock );
                          }
	YY_BREAK
case 91:
/* rule 91 can match eol */
YY_RULE_SETUP
#line 559 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            bool javadocBanner = Config_getBool(JAVADOC_BANNER);
                            yyextra->cCodeBuffer += yytext;
                            if( javadocBanner )
                            {
                              yyextra->docBlockContext   = YY_START;
                              BEGIN( DocBlock );
                            }
                            else
                            {
                              BEGIN( Comment ) ;
                            }
                          }
	YY_BREAK
case 92:
/* rule 92 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 572 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                             yyextra->cCodeBuffer += yytext;
                             yyextra->docBlockContext   = YY_START;
                             BEGIN( DocBlock );
                          }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 577 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                            yyextra->docBlockContext   = YY_START;
                            BEGIN( DocLine );
                          }
	YY_BREAK
case 94:
/* rule 94 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 3);
yyg->yy_c_buf_p = yy_cp = yy_bp + 3;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 582 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                            yyextra->docBlockContext   = YY_START;
                            BEGIN( DocLine );
                          }
	YY_BREAK
case 95:
/* rule 95 can match eol */
YY_RULE_SETUP
#line 588 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                            if (yyextra->curlyCount<=0)
                            {
                              BEGIN(RulesPattern);
                            }
                          }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 595 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                             yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 598 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                             yyextra->cCodeBuffer += yytext;
                             BEGIN( yyextra->lastStringContext );
                          }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 602 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 99:
/* rule 99 can match eol */
YY_RULE_SETUP
#line 605 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 608 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 101:
/* rule 101 can match eol */
YY_RULE_SETUP
#line 611 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{  // line continuation
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 102:
/* rule 102 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 614 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                            BEGIN( yyextra->lastCContext ) ;
                          }
	YY_BREAK
case 103:
/* rule 103 can match eol */
YY_RULE_SETUP
#line 618 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext ;
                          }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 621 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ yyextra->cCodeBuffer += yytext ; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 622 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ yyextra->cCodeBuffer += yytext ; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 623 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->insideCode=true;
                            yyextra->cCodeBuffer += yytext ;
                          }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 627 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->insideCode=false;
                            yyextra->cCodeBuffer += yytext ;
                          }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 631 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ yyextra->cCodeBuffer += yytext ; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 632 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ yyextra->cCodeBuffer += yytext ;
                                          if (!yyextra->insideCode) BEGIN( yyextra->lastContext ) ;
                          }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 635 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ yyextra->cCodeBuffer += *yytext ; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 637 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 640 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 113:
/* rule 113 can match eol */
YY_RULE_SETUP
#line 643 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 646 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                            BEGIN( yyextra->lastCContext );
                          }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 650 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 116:
/* rule 116 can match eol */
YY_RULE_SETUP
#line 653 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                            if (extractEndRawStringDelimiter(yytext)==yyextra->delimiter)
                            {
                              BEGIN(yyextra->lastRawStringContext);
                            }
                          }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 660 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 663 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 119:
/* rule 119 can match eol */
YY_RULE_SETUP
#line 666 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
/* ---- Single line comments ------ */
case 120:
/* rule 120 can match eol */
YY_RULE_SETUP
#line 672 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ // continuation of multiline C++-style comment
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 121:
/* rule 121 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 675 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ // ignore marker line (see bug700345)
                            yyextra->cCodeBuffer += yytext;
                            BEGIN( yyextra->docBlockContext );
                          }
	YY_BREAK
case 122:
/* rule 122 can match eol */
YY_RULE_SETUP
#line 679 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ // next line is an end group marker, see bug 752712
                            yyextra->cCodeBuffer += yytext;
                            BEGIN( yyextra->docBlockContext );
                          }
	YY_BREAK
case 123:
/* rule 123 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 683 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ // whole line
                            yyextra->cCodeBuffer += yytext;
                            BEGIN( yyextra->docBlockContext );
                          }
	YY_BREAK
/* ---- Comments blocks ------ */
case 124:
YY_RULE_SETUP
#line 690 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ // end of comment block
                            yyextra->cCodeBuffer += yytext;
                            BEGIN(yyextra->docBlockContext);
                          }
	YY_BREAK
case 125:
/* rule 125 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 694 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 126:
/* rule 126 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 697 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ // start of a comment line
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 700 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ // strip embedded C++ comments if at the start of a line
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 703 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ // slashes in the middle of a comment block
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 706 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ // start of a new comment in the
                            // middle of a comment block
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 130:
/* rule 130 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 710 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ // escaped command
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 713 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                            yyextra->docBlockName=&yytext[1];
                            if (yyextra->docBlockName.at(1)=='[')
                            {
                              yyextra->docBlockName.at(1)=']';
                            }
                            if (yyextra->docBlockName.at(1)=='{')
                            {
                              yyextra->docBlockName.at(1)='}';
                            }
                            if (yyextra->docBlockName.at(1)=='(')
                            {
                              yyextra->docBlockName.at(1)=')';
                            }
                            yyextra->fencedSize=0;
                            yyextra->nestedComment=false;
                            BEGIN(DocCopyBlock);
                          }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 732 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                            yyextra->docBlockName="<pre>";
                            yyextra->fencedSize=0;
                            yyextra->nestedComment=false;
                            BEGIN(DocCopyBlock);
                          }
	YY_BREAK
case 133:
/* rule 133 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 739 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ // verbatim type command (which could contain nested comments!)
                            yyextra->cCodeBuffer += yytext;
                            yyextra->docBlockName="uml";
                            yyextra->fencedSize=0;
                            yyextra->nestedComment=false;
                            BEGIN(DocCopyBlock);
                          }
	YY_BREAK
case 134:
/* rule 134 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 746 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ // verbatim command (which could contain nested comments!)
                            yyextra->cCodeBuffer += yytext;
                            yyextra->docBlockName=&yytext[1];
                            yyextra->fencedSize=0;
                            yyextra->nestedComment=false;
                            BEGIN(DocCopyBlock);
                          }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 753 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                            DString pat = substitute(yytext,"*"," ");
                            yyextra->docBlockName="~~~";
                            yyextra->fencedSize=pat.stripWhiteSpace().length();
                            yyextra->nestedComment=false;
                            BEGIN(DocCopyBlock);
                          }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 761 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                            DString pat = substitute(yytext,"*"," ");
                            yyextra->docBlockName="```";
                            yyextra->fencedSize=pat.stripWhiteSpace().length();
                            yyextra->nestedComment=false;
                            BEGIN(DocCopyBlock);
                          }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 769 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            REJECT;
                          }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 772 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ // any character that isn't special
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 139:
/* rule 139 can match eol */
YY_RULE_SETUP
#line 775 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ // newline
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 778 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ // command block
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
/* ---- Copy verbatim sections ------ */
case 141:
YY_RULE_SETUP
#line 783 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ // end of a <pre> block
                            yyextra->cCodeBuffer += yytext;
                            if (yyextra->docBlockName=="<pre>")
                            {
                              BEGIN(DocBlock);
                            }
                          }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 790 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ // end of a <code> block
                            yyextra->cCodeBuffer += yytext;
                            if (yyextra->docBlockName=="<code>")
                            {
                              BEGIN(DocBlock);
                            }
                          }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 797 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                            if (yyextra->docBlockName==&yytext[1])
                            {
                              BEGIN(DocBlock);
                            }
                          }
	YY_BREAK
case 144:
/* rule 144 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 804 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ // end of verbatim block
                            yyextra->cCodeBuffer += yytext;
                            if (yyextra->docBlockName==&yytext[4])
                            {
                              BEGIN(DocBlock);
                            }
                          }
	YY_BREAK
case 145:
/* rule 145 can match eol */
YY_RULE_SETUP
#line 811 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ // start of a comment line
                            yyextra->cCodeBuffer += yytext;
                            if ((yyextra->docBlockName=="verbatim") || (yyextra->docBlockName=="code") || (yyextra->docBlockName=="iliteral"))
                            {
                              REJECT;
                            }
                            else
                            {
                              yyextra->cCodeBuffer += yytext;
                            }
                          }
	YY_BREAK
case 146:
/* rule 146 can match eol */
YY_RULE_SETUP
#line 822 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ // start of a comment line with two *'s
                            if ((yyextra->docBlockName=="code") || (yyextra->docBlockName=="iliteral"))
                            {
                              yyextra->cCodeBuffer += yytext;
                            }
                            else
                            {
                              REJECT;
                            }
                          }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 832 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ // Assume *var or *(... is part of source code (see bug723516)
                            if ((yyextra->docBlockName=="code") || (yyextra->docBlockName=="iliteral"))
                            {
                              yyextra->cCodeBuffer += yytext;
                            }
                            else
                            {
                              REJECT;
                            }
                          }
	YY_BREAK
case 148:
/* rule 148 can match eol */
YY_RULE_SETUP
#line 842 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ // start of a comment line with one *
                            if ((yyextra->docBlockName=="code") || (yyextra->docBlockName=="iliteral"))
                            {
                              if (yyextra->nestedComment) // keep * it is part of the code
                              {
                                yyextra->cCodeBuffer += yytext;
                              }
                              else // remove * it is part of the comment block
                              {
                                yyextra->cCodeBuffer += yytext;
                              }
                            }
                            else
                            {
                              REJECT;
                            }
                          }
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 859 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                            DString pat = substitute(yytext,"*"," ");
                            if (yyextra->docBlockName == "~~~" && yyextra->fencedSize==pat.stripWhiteSpace().length())
                            {
                              BEGIN(DocBlock);
                            }
                          }
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 867 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                            DString pat = substitute(yytext,"*"," ");
                            if (yyextra->docBlockName == "```" && yyextra->fencedSize==pat.stripWhiteSpace().length())
                            {
                              BEGIN(DocBlock);
                            }
                          }
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 875 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ // any character that is not special
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 878 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            if (yytext[1]=='*')
                            {
                              yyextra->nestedComment=true;
                            }
                            else if (yytext[0]=='*')
                            {
                              yyextra->nestedComment=false;
                            }
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 153:
/* rule 153 can match eol */
YY_RULE_SETUP
#line 889 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ // newline
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 892 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ // any other character
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
case 155:
/* rule 155 can match eol */
YY_RULE_SETUP
#line 895 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{ // desc is followed by another one
                            yyextra->docBlockContext   = SkipCurlyEndDoc;
                            yyextra->cCodeBuffer += yytext;
                            if (yytext[yyleng-3]=='/')
                            {
                              BEGIN( DocLine );
                            }
                            else
                            {
                              BEGIN( DocBlock );
                            }
                          }
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 907 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                            BEGIN(SkipCurly);
                          }
	YY_BREAK
case 157:
/* rule 157 can match eol */
YY_RULE_SETUP
#line 912 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            yyextra->cCodeBuffer += yytext;
                          }
	YY_BREAK
/*
<*>.  { fprintf(stderr,"Lex scanner Def rule for %s: #%s#\n",stateToString(YY_START),yytext);}
<*>{nl}  { fprintf(stderr,"Lex scanner Def rule for newline %s: #%s#\n",stateToString(YY_START),yytext);}
 */
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(DefSection):
case YY_STATE_EOF(Option):
case YY_STATE_EOF(OptPrefix):
case YY_STATE_EOF(DefSectionLine):
case YY_STATE_EOF(RulesSectionInit):
case YY_STATE_EOF(RulesPattern):
case YY_STATE_EOF(RulesDouble):
case YY_STATE_EOF(RulesRoundDouble):
case YY_STATE_EOF(RulesSquare):
case YY_STATE_EOF(RulesRoundSquare):
case YY_STATE_EOF(RulesRound):
case YY_STATE_EOF(RulesRoundQuest):
case YY_STATE_EOF(UserSection):
case YY_STATE_EOF(TopSection):
case YY_STATE_EOF(LiteralSection):
case YY_STATE_EOF(COMMENT):
case YY_STATE_EOF(SkipCurly):
case YY_STATE_EOF(SkipCurlyEndDoc):
case YY_STATE_EOF(PreLineCtrl):
case YY_STATE_EOF(DocLine):
case YY_STATE_EOF(DocBlock):
case YY_STATE_EOF(DocCopyBlock):
case YY_STATE_EOF(SkipString):
case YY_STATE_EOF(RawString):
case YY_STATE_EOF(SkipComment):
case YY_STATE_EOF(SkipCxxComment):
case YY_STATE_EOF(Comment):
#line 921 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
{
                            handleCCode(yyscanner);
                            yyterminate();
                          }
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 925 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"
ECHO;
	YY_BREAK
#line 3865 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner_intermediate.cpp"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;
	yy_current_state += YY_AT_BOL();

	yyg->yy_state_ptr = yyg->yy_state_buf;
	*yyg->yy_state_ptr++ = yy_current_state;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 797 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		*yyg->yy_state_ptr++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */

	YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 797 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 796);
	if ( ! yy_is_jam )
		*yyg->yy_state_ptr++ = yy_current_state;

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp , yyscan_t yyscanner)
{
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yy_cp = yyg->yy_c_buf_p;

	/* undo effects of setting up yytext */
	*yy_cp = yyg->yy_hold_char;

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = yyg->yy_n_chars + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			yyg->yy_n_chars = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	yyg->yytext_ptr = yy_bp;
	yyg->yy_hold_char = *yy_cp;
	yyg->yy_c_buf_p = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

    yyg->yy_state_buf = 0;
    yyg->yy_state_ptr = 0;
    yyg->yy_full_match = 0;
    yyg->yy_lp = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    yyfree ( yyg->yy_state_buf , yyscanner);
    yyg->yy_state_buf  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 925 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/lexscanner.l"


//----------------------------------------------------------------------------
static int yyread(yyscan_t yyscanner,char *buf,int max_size)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  int c=0;
  while( c < max_size && yyextra->inputString[yyextra->inputPosition] )
  {
    *buf = yyextra->inputString[yyextra->inputPosition++] ;
    //printf("%d (%c)\n",*buf,*buf);
    c++; buf++;
  }
  return c;
}

//-----------------------------------------------------------------------------

static void parseMain(yyscan_t yyscanner,
                      const DString &fileName,
                      const char *fileBuf,
                      const std::shared_ptr<Entry> &rt,
                      ClangTUParser *clangParser)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;

  yyextra->inputString = fileBuf;
  yyextra->inputPosition = 0;
  lexscannerYYrestart(0,yyscanner);

  yyextra->current_root  = rt;
  yyextra->fileName = fileName;
  yyextra->clangParser = clangParser;
  yyextra->language    = getLanguageFromFileName(yyextra->fileName);
  rt->lang = yyextra->language;
  msg("Parsing file {}...\n",yyextra->fileName);

  yyextra->current_root  = rt;
  yyextra->current = std::make_shared<Entry>();
  EntryType sec=guessSection(yyextra->fileName);
  if (!sec.isEmpty())
  {
    yyextra->current->name    = yyextra->fileName;
    yyextra->current->section = EntryType(sec);
    yyextra->current_root->moveToSubEntryAndRefresh(yyextra->current);
  }
  yyextra->current->reset();
  BEGIN( DefSection );

  lexscannerYYlex(yyscanner);

  rt->program.str(std::string());
}

//----------------------------------------------------------------------------


static void handleCCode(yyscan_t yyscanner)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;

  if (yyextra->cCodeBuffer.empty()) return;
  yyextra->cOutlineParser.parseInput(yyextra->fileName,
                                     yyextra->cCodeBuffer.data(),
                                     yyextra->current_root,
                                     yyextra->clangParser);
  yyextra->cCodeBuffer.clear();
  return;
}
//----------------------------------------------------------------------------

struct LexOutlineParser::Private
{
  yyscan_t yyscanner;
  lexscannerYY_state state;
};

LexOutlineParser::LexOutlineParser() : p(std::make_unique<LexOutlineParser::Private>())
{
  lexscannerYYlex_init_extra(&p->state,&p->yyscanner);
#ifdef FLEX_DEBUG
  lexscannerYYset_debug(Debug::isFlagSet(Debug::Lex_lexscanner)?1:0,p->yyscanner);
#endif
}

LexOutlineParser::~LexOutlineParser()
{
  lexscannerYYlex_destroy(p->yyscanner);
}

void LexOutlineParser::parseInput(const DString &fileName,
                                  const char *fileBuf,
                                  const std::shared_ptr<Entry> &root,
                                  ClangTUParser *clangParser)
{
  struct yyguts_t *yyg = (struct yyguts_t*)p->yyscanner;

  yyextra->fileName      = fileName;
  DebugLex debugLex(Debug::Lex_lexscanner, __FILE__, qPrint(fileName));

  ::parseMain(p->yyscanner,fileName,fileBuf,root,clangParser);
}


//----------------------------------------------------------------------------

#include "lexscanner.l.h"

